"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("@rtcts/utils");
const defaultExecutor = async (flags) => {
    console.log("Executor", flags);
};
class Command {
    constructor(name, executor = defaultExecutor) {
        this.name = name;
        this.flags = new Set();
        this.executor = executor;
        this.leafs = new Set();
        this.addCommand = this.addCommand.bind(this);
        this.addFlag = this.addFlag.bind(this);
        this.getExecutor = this.getExecutor.bind(this);
        this.getFlags = this.getFlags.bind(this);
        this.getHelp = this.getHelp.bind(this);
    }
    addCommand(leaf) {
        this.leafs.add(leaf);
    }
    addFlag(flag) {
        this.flags.add(flag);
    }
    getExecutor(commands) {
        const [command_name, next_command_name, next_commands] = this.preparedCommands(commands);
        if (command_name === this.name && next_command_name !== "help") {
            if (this.leafs.size > 0) {
                for (const leaf of this.leafs) {
                    if (leaf.name === next_command_name) {
                        return leaf.getExecutor(next_commands);
                    }
                }
            }
            else {
                return this.executor;
            }
        }
    }
    getFlags(commands, prev_flag_values = {}) {
        const [command_name, next_command_name, next_commands] = this.preparedCommands(commands);
        const cur_flag_values = { ...prev_flag_values };
        for (const flag of this.flags) {
            const flag_name = flag.replace("--", "");
            cur_flag_values[flag_name] = commands.includes(flag);
        }
        if (command_name === this.name) {
            if (this.leafs.size > 0) {
                for (const leaf of this.leafs) {
                    if (leaf.name === next_command_name) {
                        return leaf.getFlags(next_commands, cur_flag_values);
                    }
                }
            }
            else {
                return cur_flag_values;
            }
        }
        return cur_flag_values;
    }
    getHelp(commands, prev_command_path, prev_flags = new Set(), skip_command_check = false) {
        const [command_name, next_command_name, next_commands] = this.preparedCommands(commands);
        let command_path = this.name;
        let flags = new Set(prev_flags);
        if (utils_1.isString(prev_command_path)) {
            command_path = `${prev_command_path} ${this.name}`;
        }
        if (this.flags.size > 0) {
            flags = new Set([...flags, ...this.flags]);
        }
        if (!skip_command_check) {
            if (command_name === this.name && next_command_name !== "help") {
                if (this.leafs.size > 0) {
                    for (const leaf of this.leafs) {
                        if (leaf.name === next_command_name && next_command_name !== "help") {
                            return leaf.getHelp(next_commands, command_path, flags, false);
                        }
                    }
                }
                else {
                    return [];
                }
            }
        }
        let help = [];
        if (this.leafs.size > 0) {
            for (const leaf of this.leafs) {
                const result_helps = leaf.getHelp(next_commands, command_path, flags, true);
                help = [...help, ...result_helps];
            }
        }
        else {
            if (flags.size > 0) {
                help.push(`${command_path} [ ${Array.from(flags).join(" | ")} ]`);
            }
            else {
                help.push(command_path);
            }
        }
        return help;
    }
    preparedCommands(commands) {
        const [command_name, next_command_name, ...other_commands] = commands;
        const next_commands = [next_command_name, ...other_commands];
        return [command_name, next_command_name, next_commands];
    }
}
exports.Command = Command;
//# sourceMappingURL=Command.js.map