"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const moment_1 = __importDefault(require("moment"));
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const RearguardDevConfig_1 = require("../../configs/RearguardDevConfig");
const processQueue_1 = require("../../helpers/processQueue");
const buildBrowserApp_1 = require("../procedures/build/buildBrowserApp");
const buildDllBundles_1 = require("../procedures/build/buildDllBundles");
const buildOutdatedDependency_1 = require("../procedures/build/buildOutdatedDependency");
const buildUnfinishedDependencies_1 = require("../procedures/build/buildUnfinishedDependencies");
const copyBundlesAndPublicToDist_1 = require("../procedures/copyBundlesAndPublicToDist");
const copyBundlesToProject_1 = require("../procedures/copyBundlesToProject");
const copyGlobalLinkedModules_1 = require("../procedures/copyGlobalLinkedModules");
const createListOfLoadOnDemand_1 = require("../procedures/createListOfLoadOnDemand");
const deleteExternalBundles_1 = require("../procedures/deleteExternalBundles");
const checkNotInstalledDependencies_1 = require("../procedures/checkNotInstalledDependencies");
async function build_browser_app(options) {
    console.log(chalk_1.default.bold.blue(`[ BROWSER ][ APP ][ BUILD ][ START ]`));
    console.log("");
    const startTime = moment_1.default();
    const CWD = process.cwd();
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const name = rearguardConfig.getName();
    const rearguardLocalConfig = new RearguardDevConfig_1.RearguardDevConfig(CWD);
    await processQueue_1.processQueue.getInQueue(name, options.bypass_the_queue);
    await rearguardLocalConfig.setBuildStatus("in_progress");
    await checkNotInstalledDependencies_1.checkNotInstalledDependencies(CWD);
    await buildUnfinishedDependencies_1.buildUnfinishedDependencies(CWD);
    await buildOutdatedDependency_1.buildOutdatedDependency(CWD);
    await deleteExternalBundles_1.deleteExternalBundles(CWD, true);
    await copyGlobalLinkedModules_1.copyGlobalLinkedModules(CWD);
    await copyBundlesToProject_1.copyBundlesToProject(CWD);
    await createListOfLoadOnDemand_1.createListOfLoadOnDemand(CWD, false);
    await buildDllBundles_1.buildDllBundles(CWD, options);
    await buildBrowserApp_1.buildBrowserApp(CWD, options);
    await copyBundlesAndPublicToDist_1.copyBundlesAndPublicToDist(CWD);
    await rearguardLocalConfig.setBuildStatus("done");
    await processQueue_1.processQueue.getOutQueue(name, options.bypass_the_queue);
    console.log("");
    console.log(chalk_1.default.bold.blue(`[ BROWSER ][ APP ][ BUILD ][ FINISH ][ ${moment_1.default().diff(startTime, "milliseconds")} ms ]`));
    console.log("");
}
exports.build_browser_app = build_browser_app;
//# sourceMappingURL=build_browser_app.js.map