"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const moment_1 = __importDefault(require("moment"));
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const RearguardDevConfig_1 = require("../../configs/RearguardDevConfig");
const processQueue_1 = require("../../helpers/processQueue");
const buildDllBundles_1 = require("../procedures/build/buildDllBundles");
const deleteExternalBundles_1 = require("../procedures/deleteExternalBundles");
const copyGlobalLinkedModules_1 = require("../procedures/copyGlobalLinkedModules");
const copyBundlesToProject_1 = require("../procedures/copyBundlesToProject");
async function build_browser_dll(options) {
    try {
        console.log(chalk_1.default.bold.blue(`[ DLL ][ BUILD ][ START ]`));
        console.log("");
        const startTime = moment_1.default();
        const CWD = process.cwd();
        const rearguardLocalConfig = new RearguardDevConfig_1.RearguardDevConfig(CWD);
        const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
        const name = rearguardConfig.getName();
        await processQueue_1.processQueue.getInQueue(name, options.bypass_the_queue);
        await rearguardLocalConfig.setBuildStatus("in_progress");
        await deleteExternalBundles_1.deleteExternalBundles(CWD, true);
        await copyGlobalLinkedModules_1.copyGlobalLinkedModules(CWD);
        await copyBundlesToProject_1.copyBundlesToProject(CWD);
        await buildDllBundles_1.buildDllBundles(CWD, options);
        await rearguardLocalConfig.setBuildStatus("done");
        await processQueue_1.processQueue.getOutQueue(name, options.bypass_the_queue);
        console.log("");
        console.log(chalk_1.default.bold.blue(`[ DLL ][ BUILD ][ FINISH ][ ${moment_1.default().diff(startTime, "milliseconds")} ms ]`));
        console.log("");
    }
    catch (error) {
        console.trace(error);
    }
}
exports.build_browser_dll = build_browser_dll;
//# sourceMappingURL=build_browser_dll.js.map