"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const moment_1 = __importDefault(require("moment"));
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const RearguardDevConfig_1 = require("../../configs/RearguardDevConfig");
const processQueue_1 = require("../../helpers/processQueue");
const buildDllBundles_1 = require("../procedures/build/buildDllBundles");
const buildLib_1 = require("../procedures/build/buildLib");
const buildLibBundles_1 = require("../procedures/build/buildLibBundles");
const buildOutdatedDependency_1 = require("../procedures/build/buildOutdatedDependency");
const buildUnfinishedDependencies_1 = require("../procedures/build/buildUnfinishedDependencies");
const copyBundlesToProject_1 = require("../procedures/copyBundlesToProject");
const copyGlobalLinkedModules_1 = require("../procedures/copyGlobalLinkedModules");
const createListOfLoadOnDemand_1 = require("../procedures/createListOfLoadOnDemand");
const deleteExternalBundles_1 = require("../procedures/deleteExternalBundles");
const updatePkgFiles_1 = require("../procedures/updatePkgFiles");
const checkNotInstalledDependencies_1 = require("../procedures/checkNotInstalledDependencies");
async function build_browser_lib(options) {
    console.log(chalk_1.default.bold.blue(`[ BROWSER ][ LIB ][ BUILD ][ START ]`));
    console.log("");
    const startTime = moment_1.default();
    const CWD = process.cwd();
    const rearguardLocalConfig = new RearguardDevConfig_1.RearguardDevConfig(CWD);
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const name = rearguardConfig.getName();
    await processQueue_1.processQueue.getInQueue(name, options.bypass_the_queue);
    await rearguardLocalConfig.setBuildStatus("in_progress");
    await updatePkgFiles_1.updatePkgFiles(CWD);
    await checkNotInstalledDependencies_1.checkNotInstalledDependencies(CWD);
    await buildUnfinishedDependencies_1.buildUnfinishedDependencies(CWD);
    await buildOutdatedDependency_1.buildOutdatedDependency(CWD);
    await deleteExternalBundles_1.deleteExternalBundles(CWD, true);
    await copyGlobalLinkedModules_1.copyGlobalLinkedModules(CWD);
    await copyBundlesToProject_1.copyBundlesToProject(CWD);
    await createListOfLoadOnDemand_1.createListOfLoadOnDemand(CWD, false);
    await buildDllBundles_1.buildDllBundles(CWD, options);
    await buildLibBundles_1.buildLibBundles(CWD, options);
    await buildLib_1.buildLib(CWD, true);
    await deleteExternalBundles_1.deleteExternalBundles(CWD);
    await rearguardLocalConfig.setBuildStatus("done");
    await processQueue_1.processQueue.getOutQueue(name, options.bypass_the_queue);
    console.log(chalk_1.default.bold.blue(`[ BROWSER ][ LIB ][ BUILD ][ FINISH ][ ${moment_1.default().diff(startTime, "milliseconds")} ms ]`));
    console.log("");
}
exports.build_browser_lib = build_browser_lib;
//# sourceMappingURL=build_browser_lib.js.map