"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const moment_1 = __importDefault(require("moment"));
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const RearguardDevConfig_1 = require("../../configs/RearguardDevConfig");
const processQueue_1 = require("../../helpers/processQueue");
const buildLib_1 = require("../procedures/build/buildLib");
const buildUnfinishedDependencies_1 = require("../procedures/build/buildUnfinishedDependencies");
const copyGlobalLinkedModules_1 = require("../procedures/copyGlobalLinkedModules");
const updatePkgFiles_1 = require("../procedures/updatePkgFiles");
const checkNotInstalledDependencies_1 = require("../procedures/checkNotInstalledDependencies");
async function build_node_lib(options) {
    console.log(chalk_1.default.bold.blue(`[ NODE ][ LIB ][ BUILD ][ START ]`));
    console.log("");
    const startTime = moment_1.default();
    const CWD = process.cwd();
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const rearguardLocalConfig = new RearguardDevConfig_1.RearguardDevConfig(CWD);
    const name = rearguardConfig.getName();
    await processQueue_1.processQueue.getInQueue(name, options.bypass_the_queue);
    await rearguardLocalConfig.setBuildStatus("in_progress");
    await updatePkgFiles_1.updatePkgFiles(CWD);
    await checkNotInstalledDependencies_1.checkNotInstalledDependencies(CWD);
    await buildUnfinishedDependencies_1.buildUnfinishedDependencies(CWD);
    await copyGlobalLinkedModules_1.copyGlobalLinkedModules(CWD);
    await buildLib_1.buildLib(CWD);
    await rearguardLocalConfig.setBuildStatus("done");
    await processQueue_1.processQueue.getOutQueue(name, options.bypass_the_queue);
    await rearguardLocalConfig.setLastBuildTime();
    console.log(chalk_1.default.bold.blue(`[ NODE ][ LIB ][ BUILD ][ FINISH ][ ${moment_1.default().diff(startTime, "milliseconds")} ms ]`));
    console.log("");
}
exports.build_node_lib = build_node_lib;
//# sourceMappingURL=build_node_lib.js.map