"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const execa_1 = __importDefault(require("execa"));
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const processQueue_1 = require("../../helpers/processQueue");
const getSortedListOfDependencies_1 = require("../procedures/getSortedListOfDependencies");
const updateVSCodeSettingsForMonoRepo_1 = require("../procedures/updateVSCodeSettingsForMonoRepo");
exports.group_command_executor = async ([command, ...params], withDll = false, bypassTheQueue = false) => {
    const CWD = process.cwd();
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const name = rearguardConfig.getName();
    const components = rearguardConfig.getComponents();
    await updateVSCodeSettingsForMonoRepo_1.updateVSCodeSettingsForMonoRepo(CWD);
    await processQueue_1.processQueue.getInQueue(name, bypassTheQueue);
    const sortedListOfMonoComponents = await getSortedListOfDependencies_1.getSortedListOfMonoComponents(CWD, components);
    try {
        for (const pathToComponent of sortedListOfMonoComponents) {
            const execaOptions = {
                stdout: "inherit",
                stderr: "inherit",
                cwd: pathToComponent,
            };
            const rearguardConfigItem = new RearguardConfig_1.RearguardConfig(pathToComponent);
            const isDll = rearguardConfigItem.isDll();
            console.log(chalk_1.default.bold.magenta(`[ ${rearguardConfigItem.getName()} ][ ${rearguardConfigItem.getVersion()} ]`));
            console.log("");
            console.log(chalk_1.default.magenta(`[ CWD ][ ${pathToComponent} ]`));
            console.log("");
            if (!isDll || withDll) {
                console.log(chalk_1.default.magenta(`[ EXECUTED COMMAND ][ ${[command, ...params].join(" ")} ]`));
                console.log("");
                await execa_1.default(command, params, execaOptions);
            }
            console.log("");
        }
    }
    catch (error) {
        console.error(error);
    }
    await processQueue_1.processQueue.getOutQueue(name, bypassTheQueue);
};
//# sourceMappingURL=executor.js.map