"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const execa_1 = __importDefault(require("execa"));
const path_1 = __importDefault(require("path"));
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const const_1 = require("../../const");
const processQueue_1 = require("../../helpers/processQueue");
const typingNonTypescriptModules_1 = require("../../templates/typingNonTypescriptModules");
const getSortedListOfDependencies_1 = require("../procedures/getSortedListOfDependencies");
const executor_1 = require("./executor");
exports.group_bootstrap_component = async (options) => {
    const CWD = process.cwd();
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const name = rearguardConfig.getName();
    const components = rearguardConfig.getComponents();
    await processQueue_1.processQueue.getInQueue(name);
    await executor_1.group_command_executor([
        "rm",
        "-rf",
        "./node_modules",
        "package-lock.json",
        const_1.DISTRIBUTIVE_DIR_NAME,
        const_1.DLL_BUNDLE_DIR_NAME,
        const_1.LIB_BUNDLE_DIR_NAME,
        const_1.LIB_DIR_NAME,
    ], true, true);
    await executor_1.group_command_executor(["npm", "install"], true, true);
    await executor_1.group_command_executor(["npm", "link"], true, true);
    const sortedListOfMonoComponents = await getSortedListOfDependencies_1.getSortedListOfMonoComponents(CWD, components);
    for (const pathToComponent of sortedListOfMonoComponents) {
        const rearguardConfigItem = new RearguardConfig_1.RearguardConfig(pathToComponent);
        const context = path_1.default.resolve(pathToComponent, rearguardConfig.getContext());
        const isDll = rearguardConfigItem.isDll();
        const isBrowser = rearguardConfigItem.isBrowser();
        const isIsomorphic = rearguardConfigItem.isIsomorphic();
        if (isBrowser || isIsomorphic) {
            await typingNonTypescriptModules_1.typingNonTypescriptModulesTemplate.render(options, context);
        }
        const execaOptions = {
            stdout: "inherit",
            stderr: "inherit",
            cwd: pathToComponent,
        };
        console.log(chalk_1.default.bold.magenta(`[ ${rearguardConfigItem.getName()} ][ ${rearguardConfigItem.getVersion()} ]`));
        console.log("");
        console.log(chalk_1.default.magenta(`[ CWD ][ ${pathToComponent} ]`));
        console.log("");
        console.log(chalk_1.default.magenta(`[ EXECUTED COMMAND ][ ${["npm", "run", "sync", "--", "--bypass_the_queue"].join(" ")} ]`));
        console.log("");
        try {
            await execa_1.default("npm", ["run", "sync", "--", "--bypass_the_queue"], execaOptions);
            if (!isDll) {
                console.log(chalk_1.default.magenta(`[ EXECUTED COMMAND ][ ${["npm", "run", "validate"].join(" ")} ]`));
                console.log("");
                await execa_1.default("npm", ["run", "validate"], execaOptions);
            }
            console.log(chalk_1.default.magenta(`[ EXECUTED COMMAND ][ ${[
                "npm",
                "run",
                "build",
                ...(options.debug ? ["--", "--debug"] : []),
                ...(options.only_dev ? ["--", "--only_dev"] : []),
                ...["--", "--bypass_the_queue"],
            ].join(" ")} ]`));
            console.log("");
            await execa_1.default("npm", [
                "run",
                "build",
                ...(options.debug ? ["--", "--debug"] : []),
                ...(options.only_dev ? ["--", "--only_dev"] : []),
                ...["--", "--bypass_the_queue"],
            ], execaOptions);
        }
        catch (error) {
            console.error(error);
        }
    }
    await processQueue_1.processQueue.getOutQueue(name);
};
//# sourceMappingURL=group_bootstrap_component.js.map