"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const execa_1 = __importDefault(require("execa"));
const semver_1 = __importDefault(require("semver"));
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const getSortedListOfDependencies_1 = require("../procedures/getSortedListOfDependencies");
const processQueue_1 = require("../../helpers/processQueue");
const executor_1 = require("./executor");
exports.group_publish_component = async (options) => {
    const CWD = process.cwd();
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const name = rearguardConfig.getName();
    const components = rearguardConfig.getComponents();
    await processQueue_1.processQueue.getInQueue(name);
    const sortedListOfMonoComponents = await getSortedListOfDependencies_1.getSortedListOfMonoComponents(CWD, components);
    for (const pathToComponent of sortedListOfMonoComponents) {
        const rearguardConfigItem = new RearguardConfig_1.RearguardConfig(pathToComponent);
        let version = rearguardConfigItem.getVersion();
        if (options.major) {
            version = semver_1.default.inc(version, "major") || version;
        }
        else if (options.minor) {
            version = semver_1.default.inc(version, "minor") || version;
        }
        else {
            version = semver_1.default.inc(version, "patch") || version;
        }
        if (semver_1.default.lte(rearguardConfigItem.getVersion(), version)) {
            await rearguardConfigItem.setVersion(version);
        }
    }
    await executor_1.group_command_executor(["npm", "run", "build", "--", "--bypass_the_queue"], true);
    try {
        for (const pathToComponent of sortedListOfMonoComponents) {
            const rearguardConfigItem = new RearguardConfig_1.RearguardConfig(pathToComponent);
            console.log(chalk_1.default.bold.magenta(`[ ${rearguardConfigItem.getName()} ][ ${rearguardConfigItem.getVersion()} ]`));
            console.log("");
            console.log(chalk_1.default.magenta(`[ CWD ][ ${pathToComponent} ]`));
            console.log("");
            console.log(chalk_1.default.magenta(`[ EXECUTED COMMAND ][ ${["npm", "publish"].join(" ")} ]`));
            console.log("");
            const execaOptions = {
                stdout: "inherit",
                stderr: "inherit",
                cwd: pathToComponent,
            };
            await execa_1.default("npm", ["publish"], execaOptions);
        }
    }
    catch (error) {
        console.error(error);
    }
    console.log("");
    await processQueue_1.processQueue.getOutQueue(name);
};
//# sourceMappingURL=group_publish_component.js.map