"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const inquirer_1 = __importDefault(require("inquirer"));
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const getSortedListOfDependencies_1 = require("../procedures/getSortedListOfDependencies");
const execa_1 = __importDefault(require("execa"));
exports.group_start_component = async (options) => {
    const CWD = process.cwd();
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const components = rearguardConfig.getComponents();
    const sortedListOfMonoComponents = await getSortedListOfDependencies_1.getSortedListOfMonoComponents(CWD, components);
    const question = {
        type: "list",
        name: "toStart",
        message: `Select the application to run`,
        choices: [],
    };
    const apps = new Map();
    for (const pathToComponent of sortedListOfMonoComponents) {
        const rearguardConfigItem = new RearguardConfig_1.RearguardConfig(pathToComponent);
        const name = rearguardConfigItem.getName();
        const isApp = rearguardConfigItem.isApp();
        if (isApp) {
            question.choices.push(name);
            apps.set(name, pathToComponent);
        }
    }
    const { toStart } = await inquirer_1.default.prompt([question]);
    const appCWD = apps.get(toStart);
    const execaOptions = {
        stdout: "inherit",
        stderr: "inherit",
        cwd: appCWD,
    };
    try {
        await execa_1.default("npm", [
            "run",
            "start",
            ...(options.release ? ["--", "--release"] : []),
            ...(options.debug ? ["--", "--debug"] : []),
            ...(options.ts_node_dev ? ["--", "--ts_node_dev"] : []),
        ], execaOptions);
    }
    catch (error) {
        console.error(error);
    }
};
//# sourceMappingURL=group_start_component.js.map