"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const RearguardDevConfig_1 = require("../../configs/RearguardDevConfig");
const TypescriptConfig_1 = require("../../configs/TypescriptConfig");
const const_1 = require("../../const");
const gitignore_1 = require("../../templates/gitignore");
const prettierignore_1 = require("../../templates/prettierignore");
const createEntryPoints_1 = require("../procedures/createEntryPoints");
const initPackage_1 = require("../procedures/initPackage");
const checkDependencies_1 = require("../procedures/checkDependencies");
async function init_browser_dll(options) {
    const CWD = process.cwd();
    await initPackage_1.initPackage(CWD);
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const rearguardLocalConfig = new RearguardDevConfig_1.RearguardDevConfig(CWD);
    const typescriptConfig = new TypescriptConfig_1.TypescriptConfig(CWD);
    const context = rearguardConfig.getContext();
    const exclude = ["node_modules", const_1.DLL_BUNDLE_DIR_NAME];
    await rearguardLocalConfig.setBuildStatus("init");
    await rearguardConfig.setRuntime("browser");
    await rearguardConfig.setType("dll");
    await rearguardConfig.setFiles([const_1.DLL_BUNDLE_DIR_NAME]);
    await prettierignore_1.prettierIgnoreTemplate.render(options);
    await rearguardConfig.setScripts({
        build: "rearguard build",
        sync: "rearguard sync",
        refresh: "rearguard refresh",
    }, options.force);
    await createEntryPoints_1.createEntryPoints(CWD);
    await typescriptConfig.init(rearguardConfig.isOverwriteTSConfig());
    await typescriptConfig.setBaseUrl(context);
    await typescriptConfig.setInclude([context]);
    await typescriptConfig.setExclude(exclude);
    await gitignore_1.gitignoreTemplate.render({
        publish_to_git: rearguardConfig.isPublishToGit(),
        listOfModulesWhichLoadOnDemand: const_1.LIST_OF_MODULES_WHICH_LOAD_ON_DEMAND,
        force: rearguardConfig.isOverwriteGitIgnore() || options.force,
    });
    await checkDependencies_1.checkDependencies(CWD, options.force);
}
exports.init_browser_dll = init_browser_dll;
//# sourceMappingURL=init_browser_dll.js.map