"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const glob_1 = __importDefault(require("glob"));
const execa_1 = __importDefault(require("execa"));
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const const_1 = require("../../const");
const chalk_1 = __importDefault(require("chalk"));
const defaultFlags = { fix: false };
const checkGlobPattern = async (pattern) => {
    return new Promise((resolve, reject) => {
        glob_1.default(pattern, (error, files) => {
            if (error) {
                reject(error);
            }
            else {
                resolve(files.length > 0);
            }
        });
    });
};
const getExtensions = (hasTS, hasTSX) => {
    const extensions = [];
    if (hasTS) {
        extensions.push("ts");
    }
    if (hasTSX) {
        extensions.push("tsx");
    }
    if (extensions.length > 1) {
        return `{${extensions.join(",")}}`;
    }
    return extensions[0] || "";
};
async function lint_executor({ fix } = defaultFlags) {
    const CWD = process.cwd();
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const bin = path_1.default.resolve(CWD, const_1.BIN_DIR_NAME);
    const src = path_1.default.resolve(CWD, rearguardConfig.getContext());
    const tests = path_1.default.resolve(CWD, const_1.TESTS_DIR_NAME);
    const __tests__ = path_1.default.resolve(CWD, `__${const_1.TESTS_DIR_NAME}__`);
    const hasBin = fs_1.default.existsSync(bin);
    const hasSrc = fs_1.default.existsSync(src);
    const hasTests = fs_1.default.existsSync(tests);
    const has__Tests__ = fs_1.default.existsSync(__tests__);
    let binPattern = "";
    let srcPattern = "";
    let testsPattern = "";
    let __tests__Pattern = "";
    if (hasBin) {
        const hasTS = await checkGlobPattern(`bin/**/*.ts`);
        const hasTSX = await checkGlobPattern(`bin/**/*.tsx`);
        binPattern = getExtensions(hasTS, hasTSX);
    }
    if (hasSrc) {
        const hasTS = await checkGlobPattern(`src/**/*.ts`);
        const hasTSX = await checkGlobPattern(`src/**/*.tsx`);
        srcPattern = getExtensions(hasTS, hasTSX);
    }
    if (hasTests) {
        const hasTS = await checkGlobPattern(`tests/**/*.ts`);
        const hasTSX = await checkGlobPattern(`tests/**/*.tsx`);
        testsPattern = getExtensions(hasTS, hasTSX);
    }
    if (has__Tests__) {
        const hasTS = await checkGlobPattern(`__${const_1.TESTS_DIR_NAME}__/**/*.ts`);
        const hasTSX = await checkGlobPattern(`__${const_1.TESTS_DIR_NAME}__/**/*.tsx`);
        __tests__Pattern = getExtensions(hasTS, hasTSX);
    }
    const args = [];
    if (fix) {
        args.push("--fix");
    }
    if (binPattern !== "") {
        args.push(`bin/**/*.${binPattern}`);
    }
    if (srcPattern !== "") {
        args.push(`src/**/*.${srcPattern}`);
    }
    if (testsPattern !== "") {
        args.push(`tests/**/*.${testsPattern}`);
    }
    if (__tests__Pattern !== "") {
        args.push(`__${const_1.TESTS_DIR_NAME}__/**/*.${testsPattern}`);
    }
    try {
        await execa_1.default("eslint", [...args, "--no-error-on-unmatched-pattern"], {
            stdout: "inherit",
            stderr: "inherit",
            cwd: process.cwd(),
        });
    }
    catch (error) {
        console.log(chalk_1.default.bold.magenta(`CWD: ${process.cwd()}`));
        console.log("");
        console.log(chalk_1.default.bold.magenta(error.message));
        console.log("");
        process.exit(1);
    }
}
exports.lint_executor = lint_executor;
//# sourceMappingURL=index.js.map