"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const execa_1 = __importDefault(require("execa"));
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const targetDepKeys = new Set(["tslib"]);
const targetDevDepKeys = new Set([
    "typescript",
    "prettier",
    "pretty-quick",
    "husky",
    "eslint",
    "eslint-config-prettier",
    "@typescript-eslint/parser",
    "@typescript-eslint/eslint-plugin",
]);
exports.checkDependencies = async (CWD = process.cwd(), force = false) => {
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const isBrowser = rearguardConfig.isBrowser();
    const isIsomorphic = rearguardConfig.isIsomorphic();
    if (isBrowser || isIsomorphic) {
        targetDevDepKeys.add("eslint-plugin-react");
        targetDevDepKeys.add("normalize.css");
        targetDevDepKeys.add("stylelint");
        targetDevDepKeys.add("stylelint-config-standard");
        targetDevDepKeys.add("stylelint-config-prettier");
        targetDevDepKeys.add("stylelint-config-css-modules");
    }
    const depMap = rearguardConfig.getDependencies();
    let depKeys = Object.keys(depMap);
    const devDepMap = rearguardConfig.getDevDependencies();
    let devDepKeys = Object.keys(devDepMap);
    if (force) {
        depKeys = depKeys.filter((key) => !targetDepKeys.has(key));
        devDepKeys = devDepKeys.filter((key) => !targetDevDepKeys.has(key));
    }
    const targetDepMap = {};
    const targetDevDepMap = {};
    for (const depKey of depKeys) {
        if (!targetDevDepKeys.has(depKey)) {
            targetDepMap[depKey] = depMap[depKey];
        }
    }
    for (const devDepKey of devDepKeys) {
        if (!targetDepKeys.has(devDepKey)) {
            targetDevDepMap[devDepKey] = devDepMap[devDepKey];
        }
    }
    rearguardConfig.setDependencies(targetDepMap);
    rearguardConfig.setDevDependencies(targetDevDepMap);
    const needInstallDeps = Array.from(targetDepKeys).some((name) => !depKeys.includes(name));
    const needInstallDevDeps = Array.from(targetDevDepKeys).some((name) => !devDepKeys.includes(name));
    const execaOptions = {
        stdout: "inherit",
        stderr: "inherit",
    };
    if (needInstallDeps) {
        try {
            const curDepList = rearguardConfig.getDependencyList();
            const toInstall = Array.from(targetDepKeys).filter((name) => !curDepList.includes(name));
            await execa_1.default("npm", ["install", "-S", "-E", ...toInstall], execaOptions);
        }
        catch (error) {
            console.error(error);
        }
    }
    if (needInstallDevDeps) {
        try {
            const curDevDepList = rearguardConfig.getDevDependencyList();
            const toInstall = Array.from(targetDevDepKeys).filter((name) => !curDevDepList.includes(name));
            await execa_1.default("npm", ["install", "-D", "-E", ...toInstall], execaOptions);
        }
        catch (error) {
            console.error(error);
        }
    }
    if (needInstallDeps || needInstallDevDeps) {
        await execa_1.default("npx", ["typesync"], execaOptions);
    }
    await rearguardConfig.reformat();
};
//# sourceMappingURL=checkDependencies.js.map