"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const execa_1 = __importDefault(require("execa"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const util_1 = require("util");
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const dependencyPaths_1 = require("../../helpers/dependencyPaths");
const getSortedListOfDependencies_1 = require("./getSortedListOfDependencies");
const exist = util_1.promisify(fs_1.default.exists);
exports.checkNotInstalledDependencies = async (CWD) => {
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const dependencies = await getSortedListOfDependencies_1.getSortedListOfDependencies(CWD);
    const localNodeModulePath = dependencyPaths_1.getLocalNodeModulePath(CWD);
    const dependenciesWhichShouldBeInstalled = [];
    for (const dependency of dependencies) {
        const dependencyLocalPath = path_1.default.resolve(localNodeModulePath, dependency);
        if (!(await exist(dependencyLocalPath))) {
            const unPublishedDependency = rearguardConfig.getUnPublishedDependency();
            if (!unPublishedDependency.includes(dependency)) {
                dependenciesWhichShouldBeInstalled.push(dependency);
            }
        }
    }
    if (dependenciesWhichShouldBeInstalled.length > 0) {
        const list = dependenciesWhichShouldBeInstalled.join("\n");
        console.log(chalk_1.default.yellow.bold(`!!! ATTENTION !!!`));
        console.log("");
        console.log(chalk_1.default.yellow.bold(`Right now will installed dependencies`));
        console.log("");
        console.log(chalk_1.default.yellow(list));
        console.log("");
        console.log(chalk_1.default.blue(`npm install -S -E ${dependenciesWhichShouldBeInstalled.join(" ")}`));
        console.log("");
        try {
            await execa_1.default("npm", ["install", "-S", "-E", ...dependenciesWhichShouldBeInstalled], {
                stdout: "inherit",
                stderr: "inherit",
            });
        }
        catch (error) {
            console.error(error);
        }
        console.log("");
    }
};
//# sourceMappingURL=checkNotInstalledDependencies.js.map