"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const copy_1 = __importDefault(require("copy"));
const del_1 = __importDefault(require("del"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const dependencyPaths_1 = require("../../helpers/dependencyPaths");
const mkdir_1 = require("../../helpers/mkdir");
const getSortedListOfDependencies_1 = require("./getSortedListOfDependencies");
exports.copyGlobalLinkedModules = async (CWD) => {
    const dependencies = await getSortedListOfDependencies_1.getSortedListOfDependencies(CWD);
    if (dependencies.length === 0) {
        return;
    }
    console.log(chalk_1.default.bold.blue(`[ COPY GLOBAL LINKED MODULES TO LOCAL NODE_MODULES ]`));
    console.log("");
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const globalNodeModulePath = dependencyPaths_1.getGlobalNodeModulePath();
    const localNodeModulePath = dependencyPaths_1.getLocalNodeModulePath(CWD);
    const globalLinkedModules = [];
    const localPathForLinkedModules = [];
    for (const dependency of dependencies) {
        const dependencyGlobalPath = path_1.default.resolve(globalNodeModulePath, dependency);
        const dependencyLocalPath = path_1.default.resolve(localNodeModulePath, dependency);
        if (fs_1.default.existsSync(dependencyGlobalPath)) {
            globalLinkedModules.push([dependency, dependencyGlobalPath]);
            localPathForLinkedModules.push(dependencyLocalPath);
            console.log(chalk_1.default.white(`[ USED ][ GLOBAL_MODULE: ${dependencyGlobalPath} ]`));
        }
        else if (fs_1.default.existsSync(dependencyLocalPath)) {
            console.log(chalk_1.default.bold.yellow(`[ USED ][ LOCAL_MODULE: ${dependencyLocalPath} ]`));
        }
        else {
            console.log(chalk_1.default.red(`[ ERROR ][ You haven't link in global node_modules ${dependencyGlobalPath} or local node_modules ${dependencyLocalPath} ]`));
            console.log(chalk_1.default.red(`[ ERROR ][ You need go to the project and do [ npm link || npm install ] needs module ]`));
            process.exit(1);
        }
    }
    console.log("");
    const moduleCopyingTasks = [];
    for (const [name, CWD] of globalLinkedModules) {
        const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
        const pkgPath = rearguardConfig.pathToPackageJsonFile;
        const pkgVersion = rearguardConfig.getVersion();
        const pkgFiles = rearguardConfig.getFiles();
        const patternForFiles = [pkgPath];
        for (const pkgFile of pkgFiles) {
            const pkgFilePath = path_1.default.resolve(CWD, pkgFile);
            if (fs_1.default.existsSync(pkgFilePath)) {
                patternForFiles.push(`${pkgFilePath}/**`);
            }
            else {
                console.log(chalk_1.default.red(`[ COPY_TASK ][ ERROR ][ module haven't file: ${pkgFilePath} ]`));
                console.log("");
                process.exit(1);
            }
        }
        moduleCopyingTasks.push([name, pkgVersion, patternForFiles]);
    }
    for (const localPathForLinkedModule of localPathForLinkedModules) {
        if (fs_1.default.existsSync(localPathForLinkedModule)) {
            const paths = await del_1.default(localPathForLinkedModule);
            for (const item of paths) {
                console.log(chalk_1.default.gray(`[ REMOVE  ][ MODULE ][ DIR ][ ${path_1.default.relative(CWD, item)} ]`));
            }
            mkdir_1.mkdir(localPathForLinkedModule);
            const relativePathToLocalModule = path_1.default.relative(CWD, localPathForLinkedModule);
            console.log(chalk_1.default.green(`[ CREATED ][ MODULE ][ DIR ][ ${relativePathToLocalModule} ]`));
        }
    }
    console.log("");
    for (const [name, pkgVersion, patternForFiles] of moduleCopyingTasks) {
        await new Promise((resolve, reject) => {
            copy_1.default(patternForFiles, path_1.default.resolve(localNodeModulePath, name), (error, files) => {
                if (!error) {
                    if (files) {
                        console.log(chalk_1.default.cyan(`[ COPY ][ MODULE ][ ${name} ][ ${files.length} FILES ]`));
                    }
                    resolve();
                }
                else {
                    reject(error);
                }
            });
        });
        await rearguardConfig.setDependencyVersion(name, pkgVersion);
    }
    console.log("");
};
//# sourceMappingURL=copyGlobalLinkedModules.js.map