"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = require("path");
const prettier_1 = __importDefault(require("prettier"));
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const const_1 = require("../../const");
const bundleNaming_1 = require("../../helpers/bundleNaming");
const getBundleIntrospection_1 = require("./getBundleIntrospection");
const util_1 = require("util");
const exists = util_1.promisify(fs_1.default.exists);
const writeFile = util_1.promisify(fs_1.default.writeFile);
exports.createListOfLoadOnDemand = async (CWD, isDevelopment) => {
    const bundleIntrospections = await getBundleIntrospection_1.getBundleIntrospections(CWD, isDevelopment);
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const content = [];
    const buildListOfLoadOnDemandModulesForAll = rearguardConfig.buildListOfLoadOnDemandModulesForAll();
    for (const { pkgSnakeName, hasDll, hasBrowserLib, assetsPath, willLoadOnDemand, } of bundleIntrospections) {
        if (willLoadOnDemand || buildListOfLoadOnDemandModulesForAll) {
            const dllName = bundleNaming_1.getDLLRuntimeName(pkgSnakeName);
            const libName = bundleNaming_1.getLIBRuntimeName(pkgSnakeName);
            let libPublicPath = "";
            if (await exists(assetsPath.lib)) {
                libPublicPath = require(assetsPath.lib)[libName].js;
            }
            if (hasDll && !hasBrowserLib) {
                let dllPublicPath = "";
                if (await exists(assetsPath.dll)) {
                    dllPublicPath = require(assetsPath.dll)[dllName].js;
                }
                content.push(`export const ${pkgSnakeName}: LoadOnDemand = ` +
                    `{ dll: [ "${dllName}" , "${dllPublicPath}" ], lib: [] };`);
            }
            if (hasDll && hasBrowserLib) {
                let dllPublicPath = "";
                if (await exists(assetsPath.dll)) {
                    dllPublicPath = require(assetsPath.dll)[dllName].js;
                }
                content.push(`export const ${pkgSnakeName}: LoadOnDemand = ` +
                    `{ dll: [ "${dllName}" , "${dllPublicPath}" ], lib: [ "${libName}", "${libPublicPath}" ] };`);
            }
            if (!hasDll && hasBrowserLib) {
                content.push(`export const ${pkgSnakeName}: LoadOnDemand = { dll: [], lib: [ "${libName}", "${libPublicPath}" ] };`);
            }
        }
    }
    if (content.length > 0) {
        content.unshift("export declare type LoadOnDemand = { dll: string[], lib: string[] }; \n\r");
        content.unshift("/* eslint-disable @typescript-eslint/camelcase */ \n\r");
        await writeFile(path_1.resolve(CWD, rearguardConfig.getContext(), const_1.LIST_OF_MODULES_WHICH_LOAD_ON_DEMAND), prettier_1.default.format(content.join(" "), const_1.PRETTIER_DEFAULT));
    }
};
//# sourceMappingURL=createListOfLoadOnDemand.js.map