"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const del_1 = __importDefault(require("del"));
const fs_1 = __importDefault(require("fs"));
const lodash_1 = require("lodash");
const path_1 = __importDefault(require("path"));
const const_1 = require("../../const");
const getSortedListOfDependencies_1 = require("./getSortedListOfDependencies");
exports.deleteExternalBundles = async (CWD, deleteAll = false) => {
    try {
        const dependencies = await getSortedListOfDependencies_1.getSortedListOfDependencies(CWD);
        const pathToDllBundleDir = path_1.default.resolve(CWD, const_1.DLL_BUNDLE_DIR_NAME);
        const pathToLibBundleDir = path_1.default.resolve(CWD, const_1.LIB_BUNDLE_DIR_NAME);
        const pathToLibDir = path_1.default.resolve(CWD, const_1.LIB_DIR_NAME);
        const needDelete = [];
        if (deleteAll) {
            if (fs_1.default.existsSync(pathToLibDir)) {
                needDelete.push(pathToLibDir);
            }
            if (fs_1.default.existsSync(pathToDllBundleDir)) {
                needDelete.push(pathToDllBundleDir);
            }
            if (fs_1.default.existsSync(pathToLibBundleDir)) {
                needDelete.push(pathToLibBundleDir);
            }
        }
        else {
            for (const dependency of dependencies) {
                const externalSnakeName = lodash_1.snakeCase(dependency);
                if (fs_1.default.existsSync(pathToDllBundleDir)) {
                    needDelete.push(path_1.default.resolve(CWD, const_1.DLL_BUNDLE_DIR_NAME, externalSnakeName));
                }
                if (fs_1.default.existsSync(pathToLibBundleDir)) {
                    needDelete.push(path_1.default.resolve(CWD, const_1.LIB_BUNDLE_DIR_NAME, externalSnakeName));
                }
            }
        }
        const paths = await del_1.default(needDelete);
        if (fs_1.default.existsSync(pathToDllBundleDir) && fs_1.default.readdirSync(pathToDllBundleDir).length === 0) {
            for (const path of await del_1.default(pathToDllBundleDir)) {
                paths.push(path);
            }
        }
        if (fs_1.default.existsSync(pathToLibBundleDir) && fs_1.default.readdirSync(pathToLibBundleDir).length === 0) {
            for (const path of await del_1.default(pathToLibBundleDir)) {
                paths.push(path);
            }
        }
        if (paths.length > 0) {
            console.log(chalk_1.default.bold.gray(`[ CLEAN ]`));
            for (const item of paths) {
                console.log(chalk_1.default.gray(`[ REMOVE ][ ${path_1.default.relative(process.cwd(), item)} ]`));
            }
            console.log("");
        }
    }
    catch (error) {
        console.trace(error);
    }
};
//# sourceMappingURL=deleteExternalBundles.js.map