"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const bundleNaming_1 = require("../../helpers/bundleNaming");
const dependencyPaths_1 = require("../../helpers/dependencyPaths");
const getSortedListOfDependencies_1 = require("./getSortedListOfDependencies");
const util_1 = require("util");
const exists = util_1.promisify(fs_1.default.exists);
exports.getBundleIntrospections = async (CWD, isDevelopment) => {
    const dependencies = await getSortedListOfDependencies_1.getSortedListOfDependencies(CWD);
    const localNodeModulePath = dependencyPaths_1.getLocalNodeModulePath(CWD);
    const bundleIntrospections = [];
    for (const dependency of dependencies) {
        const dependencyCWD = path_1.default.resolve(localNodeModulePath, dependency);
        const rearguardConfig = new RearguardConfig_1.RearguardConfig(dependencyCWD);
        const pkgName = rearguardConfig.getName();
        const pkgSnakeName = rearguardConfig.getSnakeName();
        const isBrowser = rearguardConfig.isBrowser();
        const isLib = rearguardConfig.isLib();
        const isIsomorphic = rearguardConfig.isIsomorphic();
        const dllManifestPath = bundleNaming_1.getDLLManifestPath(CWD, pkgSnakeName, isDevelopment);
        const hasDll = await exists(dllManifestPath);
        const hasBrowserLib = (isBrowser && isLib) || isIsomorphic;
        bundleIntrospections.push({
            pkgName,
            pkgSnakeName,
            hasDll,
            hasBrowserLib,
            willLoadOnDemand: rearguardConfig.willLoadOnDemand(),
            bundleRuntimeName: {
                dll: hasDll ? bundleNaming_1.getDLLRuntimeName(pkgSnakeName) : "",
                lib: hasBrowserLib ? bundleNaming_1.getLIBRuntimeName(pkgSnakeName) : "",
            },
            assetsPath: {
                dll: hasDll ? bundleNaming_1.getDLLAssetsPath(CWD, pkgSnakeName, isDevelopment) : "",
                lib: hasBrowserLib ? bundleNaming_1.getLIBAssetsPath(CWD, pkgSnakeName, isDevelopment) : "",
            },
            dllManifestPath: hasDll ? dllManifestPath : "",
        });
    }
    return bundleIntrospections;
};
//# sourceMappingURL=getBundleIntrospection.js.map