"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("@rtcts/utils");
const chalk_1 = __importDefault(require("chalk"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const util_1 = require("util");
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const dependencyPaths_1 = require("../../helpers/dependencyPaths");
const exists = util_1.promisify(fs_1.default.exists);
const readdir = util_1.promisify(fs_1.default.readdir);
const getMonoDependencyCWD = async (CWD, monoDependencyDirs, dependency) => {
    for (const monoDependencyDir of monoDependencyDirs) {
        const pathToMonoDependency = path_1.default.resolve(CWD, monoDependencyDir);
        if (await exists(pathToMonoDependency)) {
            const dependencyDirs = (await readdir(pathToMonoDependency)).map((dirName) => path_1.default.resolve(pathToMonoDependency, dirName));
            for (const dependencyCWD of dependencyDirs) {
                const rearguardConfig = new RearguardConfig_1.RearguardConfig(dependencyCWD);
                if (dependency === rearguardConfig.getName()) {
                    return dependencyCWD;
                }
            }
        }
    }
};
exports.getMapOfDependencies = async (CWD, monoDependencyDirs, mapOfDependencies = new Map(), target = "", searchInMonoDirectory = false) => {
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const dependencies = await rearguardConfig.getDependenciesCreatedWithRearguard(monoDependencyDirs, searchInMonoDirectory);
    const globalNodeModulePath = dependencyPaths_1.getGlobalNodeModulePath();
    for (const dependency of dependencies) {
        if (monoDependencyDirs.length > 0) {
            const monoDependencyCWD = await getMonoDependencyCWD(CWD, monoDependencyDirs, dependency);
            if (monoDependencyCWD && (await exists(monoDependencyCWD))) {
                const monoRearguardConfig = new RearguardConfig_1.RearguardConfig(monoDependencyCWD);
                const monoDependencies = await monoRearguardConfig.getDependenciesCreatedWithRearguard();
                if (!mapOfDependencies.has(dependency)) {
                    mapOfDependencies.set(monoDependencyCWD, monoDependencies.size);
                }
                const targetWeight = mapOfDependencies.get(target);
                if (utils_1.isNumber(targetWeight)) {
                    mapOfDependencies.set(target, targetWeight + monoDependencies.size);
                }
                await exports.getMapOfDependencies(monoDependencyCWD, monoDependencyDirs, mapOfDependencies, target === "" ? monoDependencyCWD : target, false);
                continue;
            }
            continue;
        }
        const globalDependencyCWD = path_1.default.resolve(globalNodeModulePath, dependency);
        if (await exists(globalDependencyCWD)) {
            const globalRearguardConfig = new RearguardConfig_1.RearguardConfig(globalDependencyCWD);
            const globalDependencies = await globalRearguardConfig.getDependenciesCreatedWithRearguard();
            if (!mapOfDependencies.has(dependency)) {
                mapOfDependencies.set(dependency, globalDependencies.size);
            }
            const targetWeight = mapOfDependencies.get(target);
            if (utils_1.isNumber(targetWeight)) {
                mapOfDependencies.set(target, targetWeight + globalDependencies.size);
            }
            await exports.getMapOfDependencies(globalDependencyCWD, monoDependencyDirs, mapOfDependencies, target === "" ? dependency : target);
            continue;
        }
        const localDependencyCWD = RearguardConfig_1.RearguardConfig.findDependencyInParentNodeModules(CWD, dependency);
        if (await exists(localDependencyCWD)) {
            const localRearguardConfig = new RearguardConfig_1.RearguardConfig(localDependencyCWD);
            const localDependencies = await localRearguardConfig.getDependenciesCreatedWithRearguard();
            if (!mapOfDependencies.has(dependency)) {
                mapOfDependencies.set(dependency, localDependencies.size);
            }
            const targetWeight = mapOfDependencies.get(target);
            if (utils_1.isNumber(targetWeight)) {
                mapOfDependencies.set(target, targetWeight + localDependencies.size);
            }
            await exports.getMapOfDependencies(localDependencyCWD, monoDependencyDirs, mapOfDependencies, target === "" ? dependency : target);
            continue;
        }
        console.log(chalk_1.default.bold.red(`[ FLAT_LIST_OF_DEPENDENCIES ][ You haven't link in global node_modules ${globalDependencyCWD} ]`));
        console.log(chalk_1.default.bold.red(`[ FLAT_LIST_OF_DEPENDENCIES ][ You haven't local node_modules ${localDependencyCWD} ]`));
        process.exit(1);
    }
    return mapOfDependencies;
};
//# sourceMappingURL=getMapOfDependencies.js.map