"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const chokidar_1 = require("chokidar");
const lodash_debounce_1 = __importDefault(require("lodash.debounce"));
const execa_1 = __importDefault(require("execa"));
const path_1 = __importDefault(require("path"));
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const pubSub_1 = require("../../helpers/pubSub");
let inProgress = false;
let watcher;
exports.watchCurrentModules = async (CWD) => {
    const shutdown = () => {
        if (watcher) {
            console.log(chalk_1.default.bold.yellow(`[ CLOSE WATCHER FOR CURRENT MODULE OBSERVATION ]`));
            console.log("");
            watcher.close();
            watcher = undefined;
        }
    };
    shutdown();
    process.on("SIGINT", shutdown);
    process.on("exit", shutdown);
    process.on("uncaughtException", shutdown);
    process.on("unhandledRejection", shutdown);
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const chokidarOptions = {
        cwd: CWD,
        followSymlinks: false,
        ignoreInitial: true,
    };
    const directoryForWatching = path_1.default.resolve(CWD, rearguardConfig.getContext());
    console.log(chalk_1.default.bold.yellow(`[ INIT OF CURRENT MODULE OBSERVATION ]`));
    console.log("");
    console.log(chalk_1.default.yellow(`[ OBSERVATION FOR DIRECTORY: ${directoryForWatching} ]`));
    console.log("");
    watcher = chokidar_1.watch(directoryForWatching, chokidarOptions);
    await new Promise((resolve, reject) => {
        if (watcher) {
            const errorHandler = (error) => {
                shutdown();
                console.error(error);
                reject(error);
            };
            watcher.on("ready", () => {
                if (watcher) {
                    watcher.off("error", errorHandler);
                }
                resolve();
            });
            watcher.on("error", errorHandler);
        }
    });
    const reBuild = lodash_debounce_1.default(async (type, observedFiles) => {
        if (!inProgress) {
            console.log(chalk_1.default.yellow(`[ CHANGE REASON: ${chalk_1.default.bold.cyan(type)}, FILE CHANGED: ${chalk_1.default.bold.cyan(observedFiles)} ]`));
            console.log("");
            inProgress = true;
            const execaOptions = {
                cwd: CWD,
                stdout: "inherit",
                stderr: "inherit",
            };
            await execa_1.default("npm", ["run", "build"], execaOptions);
            inProgress = false;
            console.log(chalk_1.default.yellow(`[ CHANGE REASON: ${chalk_1.default.bold.cyan(type)}, PROCESSING OF CHANGES IS COMPLETE: ${chalk_1.default.bold.cyan(observedFiles)} ]`));
            console.log("");
        }
    }, 3000);
    watcher.on("error", (error) => console.error(error));
    watcher.on("all", reBuild);
    pubSub_1.pubSub.on(pubSub_1.events.SYNCED, () => reBuild(pubSub_1.events.SYNCED, pubSub_1.events.SYNCED));
};
//# sourceMappingURL=watchCurrentModules.js.map