"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const path_1 = __importDefault(require("path"));
const fs_1 = __importDefault(require("fs"));
const chokidar_1 = require("chokidar");
const getSortedListOfDependencies_1 = require("./getSortedListOfDependencies");
const dependencyPaths_1 = require("../../helpers/dependencyPaths");
const const_1 = require("../../const");
const RearguardDevConfig_1 = require("../../configs/RearguardDevConfig");
const pubSub_1 = require("../../helpers/pubSub");
const deleteExternalBundles_1 = require("./deleteExternalBundles");
const copyGlobalLinkedModules_1 = require("./copyGlobalLinkedModules");
const copyBundlesToProject_1 = require("./copyBundlesToProject");
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const processQueue_1 = require("../../helpers/processQueue");
const buildOutdatedDependency_1 = require("./build/buildOutdatedDependency");
let inProgress = false;
let watcher;
exports.watchLinkedModules = async (CWD) => {
    const shutdown = () => {
        if (watcher) {
            console.log(chalk_1.default.bold.yellow(`[ CLOSE WATCHER FOR MODULES OBSERVATION ]`));
            console.log("");
            watcher.close();
            watcher = undefined;
        }
    };
    shutdown();
    process.on("SIGINT", shutdown);
    process.on("exit", shutdown);
    process.on("uncaughtException", shutdown);
    process.on("unhandledRejection", shutdown);
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const isBrowser = rearguardConfig.isBrowser();
    const isIsomorphic = rearguardConfig.isIsomorphic();
    const name = rearguardConfig.getName();
    const dependencies = await getSortedListOfDependencies_1.getSortedListOfDependencies(CWD);
    const chokidarOptions = {
        cwd: CWD,
        followSymlinks: false,
        ignoreInitial: true,
    };
    if (dependencies.length > 0) {
        console.log(chalk_1.default.bold.yellow(`[ INIT OF MODULES OBSERVATION ]`));
        console.log("");
        const globalNodeModulePath = dependencyPaths_1.getGlobalNodeModulePath();
        const observedModules = [];
        for (const dependency of dependencies) {
            const dependencyGlobalPath = path_1.default.resolve(globalNodeModulePath, dependency);
            if (fs_1.default.existsSync(dependencyGlobalPath)) {
                console.log(chalk_1.default.yellow(`[ OBSERVED MODULE: ${dependencyGlobalPath} ]`));
                observedModules.push(path_1.default.resolve(dependencyGlobalPath, const_1.REARGUARD_DEV_CONFIG_FILE_NAME));
            }
        }
        console.log("");
        if (observedModules.length > 0) {
            watcher = chokidar_1.watch(observedModules, chokidarOptions);
            await new Promise((resolve, reject) => {
                if (watcher) {
                    const errorHandler = (error) => {
                        shutdown();
                        console.error(error);
                        reject(error);
                    };
                    watcher.on("ready", () => {
                        if (watcher) {
                            watcher.off("error", errorHandler);
                        }
                        resolve();
                    });
                    watcher.on("error", errorHandler);
                }
            });
            watcher.on("error", (error) => console.error(error));
            watcher.on("all", async (type, observedFile) => {
                if (!inProgress) {
                    const rearguardLocalConfig = new RearguardDevConfig_1.RearguardDevConfig(CWD, observedFile);
                    const status = await rearguardLocalConfig.getStatus();
                    if (status === "done" && !inProgress) {
                        console.log(chalk_1.default.yellow(`[ OBSERVED FILE CHANGED: ${observedFile} ]`));
                        console.log("");
                        inProgress = true;
                        await processQueue_1.processQueue.getInQueue(name);
                        await buildOutdatedDependency_1.buildOutdatedDependency(CWD);
                        await copyGlobalLinkedModules_1.copyGlobalLinkedModules(CWD);
                        if (isBrowser || isIsomorphic) {
                            await deleteExternalBundles_1.deleteExternalBundles(CWD);
                            await copyBundlesToProject_1.copyBundlesToProject(CWD);
                        }
                        pubSub_1.pubSub.emit(pubSub_1.events.SYNCED);
                        await processQueue_1.processQueue.getOutQueue(name);
                        inProgress = false;
                        console.log(chalk_1.default.yellow(`[ PROCESSING OF CHANGES IS COMPLETE: ${observedFile} ]`));
                        console.log("");
                    }
                }
            });
        }
        else {
            console.log(chalk_1.default.bold.yellow(`[ THERE ARE NO OBSERVABLE MODULES ]`));
            console.log("");
        }
    }
};
//# sourceMappingURL=watchLinkedModules copy.js.map