"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const execa_1 = __importDefault(require("execa"));
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const processQueue_1 = require("../../helpers/processQueue");
const updateVSCodeSettingsForMonoRepo_1 = require("../procedures/updateVSCodeSettingsForMonoRepo");
const watchCurrentModules_1 = require("../procedures/watchCurrentModules");
const watchLinkedModules_1 = require("../procedures/watchLinkedModules");
async function watch_component() {
    try {
        const CWD = process.cwd();
        const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
        const name = rearguardConfig.getName();
        const isApp = rearguardConfig.isApp();
        const isLib = rearguardConfig.isLib();
        const isIsomorphic = rearguardConfig.isIsomorphic();
        const isBrowser = rearguardConfig.isBrowser();
        const isNode = rearguardConfig.isNode();
        if (isLib && (isIsomorphic || isBrowser || isNode)) {
            await updateVSCodeSettingsForMonoRepo_1.updateVSCodeSettingsForMonoRepo(CWD);
            console.log(chalk_1.default.bold.blue(`[ TRACK CHANGES IN FILES AND BUILD ]`));
            console.log("");
            const execaOptions = {
                cwd: CWD,
                stdout: "inherit",
                stderr: "inherit",
            };
            await execa_1.default("npm", ["run", "build"], execaOptions);
            await processQueue_1.processQueue.getInQueue(name);
            await watchLinkedModules_1.watchLinkedModules(CWD);
            await watchCurrentModules_1.watchCurrentModules(CWD);
            await processQueue_1.processQueue.getOutQueue(name);
        }
        if (isApp && (isBrowser || isNode)) {
            console.log(chalk_1.default.bold.gray("rearguard watch - wasn't supported for node application"));
        }
    }
    catch (error) {
        console.error(error);
    }
}
exports.watch_component = watch_component;
//# sourceMappingURL=index.js.map