"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("@rtcts/utils");
const Rearguard_1 = require("./Rearguard");
class PackageJSON {
    constructor(data) {
        this.name = "";
        this.version = "1.0.0";
        this.homepage = "";
        this.bugs = {
            email: "dmitriy@borodin.site",
            url: "",
        };
        this.license = "MIT";
        this.author = {
            name: "Dmitriy Borodin",
            email: "dmitriy@borodin.site",
            homepage: "https://borodin.site",
        };
        this.files = [];
        this.main = "";
        this.types = "";
        this.bin = "";
        this.repository = {
            type: "",
            url: "",
        };
        this.scripts = {};
        this.engines = {
            node: ">=10 <13",
            npm: ">=6 <7",
        };
        this.browserslist = ["last 2 versions"];
        this.husky = {
            hooks: {
                ["pre-commit"]: "pretty-quick --staged",
                ["pre-push"]: "npm run validate",
            },
        };
        this.rearguard = new Rearguard_1.Rearguard(data.rearguard || {});
        for (const fieldName of ["name", "version", "homepage", "license", "main", "types", "bin"]) {
            if (utils_1.isString(data[fieldName])) {
                this[fieldName] = data[fieldName];
            }
        }
        if (utils_1.isString(data.bugs)) {
            this.bugs = data.bugs;
        }
        else if (utils_1.isObject(data.bugs)) {
            for (const fieldName of ["email", "url"]) {
                if (utils_1.isString(data.bugs[fieldName])) {
                    this.bugs[fieldName] = data.bugs[fieldName];
                }
            }
        }
        if (utils_1.isString(data.author)) {
            this.author = data.author;
        }
        else if (utils_1.isObject(data.author)) {
            for (const fieldName of ["name", "email", "homepage"]) {
                if (utils_1.isString(data.author[fieldName])) {
                    this.author[fieldName] = data.author[fieldName];
                }
            }
        }
        if (utils_1.isArray(data.files)) {
            for (const file of data.files) {
                if (utils_1.isString(file)) {
                    this.files.push(file);
                }
            }
        }
        if (utils_1.isString(data.repository)) {
            this.repository = data.repository;
        }
        else if (utils_1.isObject(data.repository)) {
            for (const fieldName of ["type", "url"]) {
                if (utils_1.isString(data.repository[fieldName])) {
                    this.repository[fieldName] = data.repository[fieldName];
                }
            }
        }
        if (utils_1.isObject(data.scripts)) {
            this.scripts = data.scripts;
        }
        if (utils_1.isString(data.engines)) {
            this.engines = data.engines;
        }
        else if (utils_1.isObject(data.engines)) {
            for (const fieldName of ["node", "npm"]) {
                if (utils_1.isString(data.engines[fieldName])) {
                    this.engines[fieldName] = data.engines[fieldName];
                }
            }
        }
        if (utils_1.isArray(data.browserslist)) {
            this.browserslist = [];
            for (const listItem of data.browserslist) {
                if (utils_1.isString(listItem)) {
                    this.browserslist.push(listItem);
                }
            }
        }
        if (utils_1.isObject(data.husky) && utils_1.isObject(data.husky.hooks)) {
            for (const fieldName of Object.keys(data.husky.hooks)) {
                if (utils_1.isString(data.husky.hooks[fieldName])) {
                    this.husky.hooks[fieldName] = data.husky.hooks[fieldName];
                }
            }
        }
        if (utils_1.isString(data.description)) {
            this.description = data.description;
        }
        if (Array.isArray(data.keywords)) {
            this.keywords = [];
            for (const keyword of data.keywords) {
                if (utils_1.isString(keyword)) {
                    this.keywords.push(keyword);
                }
            }
        }
        if (utils_1.isString(data.contributors)) {
            this.contributors = [];
            for (const contributor of data.contributors) {
                if (utils_1.isString(contributor)) {
                    this.contributors.push(contributor);
                }
                else if (utils_1.isObject(data.contributors)) {
                    const result = {};
                    for (const fieldName of ["name", "email", "homepage"]) {
                        if (utils_1.isString(data.contributors[fieldName])) {
                            contributor[fieldName] = data.contributors[fieldName];
                        }
                    }
                    this.contributors.push(result);
                }
            }
        }
        if (utils_1.isArray(data.man)) {
            this.man = [];
            for (const item of data.man) {
                if (utils_1.isString(item)) {
                    this.man.push(item);
                }
            }
        }
        else if (utils_1.isString(data.man)) {
            this.man = data.man;
        }
        if (utils_1.isObject(data.directories)) {
            this.directories = {};
            for (const fieldName of ["lib", "bin", "man", "doc", "example"]) {
                if (utils_1.isString(data.directories[fieldName])) {
                    this.directories[fieldName] = data.directories[fieldName];
                }
            }
        }
        for (const fieldName of [
            "dependencies",
            "devDependencies",
            "peerDependencies",
            "optionalDependencies",
        ]) {
            if (utils_1.isObject(data[fieldName])) {
                const result = {};
                for (const key in data[fieldName]) {
                    if (data[fieldName].hasOwnProperty(key)) {
                        if (utils_1.isString(key) && utils_1.isString(data[fieldName][key])) {
                            result[key] = data[fieldName][key];
                        }
                    }
                }
                if (Object.keys(result).length > 0) {
                    this[fieldName] = result;
                }
            }
        }
        for (const fieldName of ["bundledDependencies", "os", "cpu"]) {
            if (utils_1.isArray(data[fieldName])) {
                this[fieldName] = [];
                for (const item of data[fieldName]) {
                    if (utils_1.isString(item)) {
                        this[fieldName].push(item);
                    }
                }
            }
        }
        for (const fieldName of ["preferGlobal", "private"]) {
            if (utils_1.isBoolean(data[fieldName])) {
                this[fieldName] = data[fieldName];
            }
        }
        if (utils_1.isObject(data.publishConfig)) {
            this.publishConfig = {
                registry: "",
                access: "",
            };
            for (const fieldName of ["registry", "access"]) {
                if (utils_1.isString(data.publishConfig[fieldName])) {
                    this.publishConfig[fieldName] = data.publishConfig[fieldName];
                }
            }
        }
    }
    toJSON() {
        const { project } = this.rearguard;
        if (project.type === "mono") {
            const { browserslist, husky, bin, files, types, main, ...other } = this;
            return {
                ...other,
                husky: {
                    ["pre-push"]: "npm run validate",
                },
            };
        }
        return this;
    }
}
exports.PackageJSON = PackageJSON;
//# sourceMappingURL=PackageJSON.js.map