"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("@rtcts/utils");
const moment_1 = __importDefault(require("moment"));
const moment_2 = require("moment");
class RearguardDev {
    constructor(data) {
        this.webpack_dev_server = {
            host: "localhost",
            port: 5000,
            proxy: {
                "/api": "http://localhost:10000",
                "/ws": {
                    changeOrigin: true,
                    target: "ws://localhost:10001",
                    ws: true,
                },
            },
        };
        this.webpack_bundle_analyzer = {
            analyzerMode: "server",
            analyzerHost: "localhost",
            analyzerPort: 20000,
            reportFilename: "webpack_bundle_analyzer",
            defaultSizes: "stat",
            openAnalyzer: true,
            generateStatsFile: false,
            statsFilename: "webpack_bundle_analyzer_stats",
            logLevel: "warn",
        };
        this.build = {
            status: "done",
            hash_dev: "N/A",
            hash_prod: "N/A",
            has_last_build_time: false,
            last_build_time: moment_1.default(),
        };
        if (data) {
            if (utils_1.isObject(data.webpack_dev_server)) {
                if (utils_1.isString(data.webpack_dev_server.host)) {
                    this.webpack_dev_server.host = data.webpack_dev_server.host;
                }
                if (utils_1.isNumber(data.webpack_dev_server.port)) {
                    this.webpack_dev_server.port = data.webpack_dev_server.port;
                }
                if (utils_1.isObject(data.webpack_dev_server.proxy)) {
                    this.webpack_dev_server.proxy = data.webpack_dev_server.proxy;
                }
            }
            if (utils_1.isObject(data.webpack_bundle_analyzer)) {
                if (["server", "static", "disabled"].includes(data.webpack_bundle_analyzer.analyzerMode)) {
                    this.webpack_bundle_analyzer.analyzerMode = data.webpack_bundle_analyzer.analyzerMode;
                }
                for (const fieldName of ["analyzerHost", "reportFilename", "statsFilename"]) {
                    if (utils_1.isString(data.webpack_bundle_analyzer[fieldName])) {
                        this.webpack_bundle_analyzer[fieldName] = data.webpack_bundle_analyzer[fieldName];
                    }
                }
                if (utils_1.isNumber(data.webpack_bundle_analyzer.analyzerPort)) {
                    this.webpack_bundle_analyzer.analyzerPort = data.webpack_bundle_analyzer.analyzerPort;
                }
                if (["parsed", "stat", "gzip"].includes(data.webpack_bundle_analyzer.defaultSizes)) {
                    this.webpack_bundle_analyzer.defaultSizes = data.webpack_bundle_analyzer.defaultSizes;
                }
                for (const fieldName of ["openAnalyzer", "generateStatsFile"]) {
                    if (utils_1.isBoolean(data.webpack_bundle_analyzer[fieldName])) {
                        this.webpack_bundle_analyzer[fieldName] = data.webpack_bundle_analyzer[fieldName];
                    }
                }
                if (["info", "warn", "error", "silent"].includes(data.webpack_bundle_analyzer.logLevel)) {
                    this.webpack_bundle_analyzer.logLevel = data.webpack_bundle_analyzer.logLevel;
                }
            }
            if (utils_1.isObject(data.build)) {
                if (["init", "in_progress", "done"].includes(data.build.status)) {
                    this.build.status = data.build.status;
                }
                for (const fieldName of ["hash_dev", "hash_prod"]) {
                    if (utils_1.isString(data.build[fieldName])) {
                        this.build[fieldName] = data.build[fieldName];
                    }
                }
                if (utils_1.isString(data.build.last_build_time)) {
                    this.build.has_last_build_time = true;
                    this.build.last_build_time = moment_1.default(data.build.last_build_time).clone();
                }
                else if (moment_2.isMoment(data.build.last_build_time)) {
                    this.build.has_last_build_time = true;
                    this.build.last_build_time = data.build.last_build_time.clone();
                }
            }
        }
    }
}
exports.RearguardDev = RearguardDev;
//# sourceMappingURL=RearguardDev.js.map