"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const lodash_1 = require("lodash");
const path_1 = __importDefault(require("path"));
const prettier_1 = __importDefault(require("prettier"));
const const_1 = require("../const");
const mkdir_1 = require("../helpers/mkdir");
const RearguardDev_1 = require("./RearguardDev");
const moment_1 = __importDefault(require("moment"));
class RearguardDevConfig {
    constructor(CWD = process.cwd(), file_path = path_1.default.resolve(CWD, const_1.REARGUARD_DEV_CONFIG_FILE_NAME)) {
        this.file_path = file_path;
    }
    async hasLastBuildTime() {
        const { build } = await this.getConfig();
        return build.has_last_build_time;
    }
    async getLastBuildTime() {
        const { build } = await this.getConfig();
        return build.last_build_time;
    }
    async getWDSConfig() {
        const config = await this.getConfig();
        return config.webpack_dev_server;
    }
    async getStatus() {
        const config = await this.getConfig();
        return config.build.status;
    }
    async setBuildStatus(status) {
        const config = await this.getConfig();
        await this.setConfig(lodash_1.merge(config, { build: { status } }));
    }
    async setLastBuildTime() {
        const config = await this.getConfig();
        await this.setConfig(lodash_1.merge(config, { build: { last_build_time: moment_1.default() } }));
    }
    async getConfig() {
        if (fs_1.default.existsSync(this.file_path)) {
            const content_of_rc_file = fs_1.default.readFileSync(this.file_path, { encoding: "utf-8" });
            try {
                return new RearguardDev_1.RearguardDev(JSON.parse(content_of_rc_file));
            }
            catch (error) {
                console.error(error);
                process.exit(1);
            }
        }
        else {
            return await this.setConfig(new RearguardDev_1.RearguardDev());
        }
        return new RearguardDev_1.RearguardDev({});
    }
    async setConfig(config) {
        const newConfig = new RearguardDev_1.RearguardDev(config);
        try {
            const content = prettier_1.default.format(JSON.stringify(newConfig), const_1.PRETTIER_JSON);
            mkdir_1.mkdir(path_1.default.dirname(this.file_path));
            fs_1.default.writeFileSync(this.file_path, content, { encoding: "utf-8" });
        }
        catch (error) {
            console.error(error);
            process.exit(1);
        }
        return newConfig;
    }
}
exports.RearguardDevConfig = RearguardDevConfig;
//# sourceMappingURL=RearguardDevConfig.js.map