"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("@rtcts/utils");
const lodash_1 = require("lodash");
class Typescript {
    constructor(data) {
        this.compileOnSave = false;
        this.compilerOptions = {
            target: "es2018",
            module: "commonjs",
            lib: ["dom", "es2018", "esnext.asynciterable"],
            allowJs: true,
            checkJs: false,
            incremental: false,
            jsx: "react",
            removeComments: true,
            skipLibCheck: true,
            forceConsistentCasingInFileNames: true,
            strict: true,
            noImplicitAny: true,
            strictNullChecks: true,
            noImplicitThis: true,
            alwaysStrict: true,
            strictFunctionTypes: true,
            strictPropertyInitialization: false,
            suppressImplicitAnyIndexErrors: true,
            suppressExcessPropertyErrors: false,
            noUnusedLocals: true,
            noUnusedParameters: false,
            noImplicitReturns: true,
            noFallthroughCasesInSwitch: true,
            moduleResolution: "node",
            baseUrl: "src",
            typeRoots: ["./types", "./node_modules/@types"],
            allowSyntheticDefaultImports: true,
            esModuleInterop: true,
            importHelpers: true,
            resolveJsonModule: true,
            sourceMap: true,
            inlineSourceMap: false,
            inlineSources: false,
            diagnostics: false,
            extendedDiagnostics: false,
            traceResolution: false,
            listEmittedFiles: false,
            listFiles: false,
            noErrorTruncation: true,
            pretty: true,
            experimentalDecorators: true,
            emitDecoratorMetadata: true,
        };
        this.include = [];
        this.exclude = [];
        if (data) {
            if (utils_1.isBoolean(data.compileOnSave)) {
                this.compileOnSave = data.compileOnSave;
            }
            if (utils_1.isArray(data.include)) {
                this.include = data.include.filter(utils_1.isString);
            }
            if (utils_1.isArray(data.exclude)) {
                this.exclude = data.exclude.filter(utils_1.isString);
            }
            if (data.compilerOptions) {
                for (const item of ["lib", "rootDirs", "typeRoots", "types"]) {
                    if (utils_1.isArray(data.compilerOptions[item])) {
                        this.compilerOptions[item] = data.compilerOptions[item].filter(utils_1.isString);
                    }
                }
                for (const item of [
                    "target",
                    "module",
                    "jsx",
                    "moduleResolution",
                    "baseUrl",
                    "sourceRoot",
                    "mapRoot",
                ]) {
                    if (utils_1.isString(data.compilerOptions[item])) {
                        this.compilerOptions[item] = data.compilerOptions[item];
                    }
                }
                for (const item of [
                    "allowJs",
                    "checkJs",
                    "incremental",
                    "removeComments",
                    "skipLibCheck",
                    "forceConsistentCasingInFileNames",
                    "strict",
                    "noImplicitAny",
                    "strictNullChecks",
                    "noImplicitThis",
                    "alwaysStrict",
                    "strictFunctionTypes",
                    "strictPropertyInitialization",
                    "suppressImplicitAnyIndexErrors",
                    "suppressExcessPropertyErrors",
                    "noUnusedLocals",
                    "noUnusedParameters",
                    "noImplicitReturns",
                    "noFallthroughCasesInSwitch",
                    "allowSyntheticDefaultImports",
                    "esModuleInterop",
                    "importHelpers",
                    "resolveJsonModule",
                    "sourceMap",
                    "inlineSourceMap",
                    "inlineSources",
                    "diagnostics",
                    "extendedDiagnostics",
                    "traceResolution",
                    "listEmittedFiles",
                    "listFiles",
                    "noErrorTruncation",
                    "pretty",
                    "experimentalDecorators",
                    "emitDecoratorMetadata",
                ]) {
                    if (utils_1.isBoolean(data.compilerOptions[item])) {
                        this.compilerOptions[item] = data.compilerOptions[item];
                    }
                }
            }
        }
    }
    static merge(origin, compilerOptions = {}, otherOptions = {}) {
        return new Typescript(lodash_1.merge(origin, { compilerOptions }, otherOptions));
    }
}
exports.Typescript = Typescript;
//# sourceMappingURL=Typescript.js.map