"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const prettier_1 = __importDefault(require("prettier"));
const const_1 = require("../const");
const mkdir_1 = require("../helpers/mkdir");
const Typescript_1 = require("./Typescript");
class TypescriptConfig {
    constructor(CWD = process.cwd(), file_name = const_1.TS_CONFIG_FILE_NAME) {
        this.CWD = CWD;
        this.file_name = file_name;
        this.file_path = path_1.default.resolve(this.CWD, this.file_name);
    }
    async init(force = false) {
        const origin = new Typescript_1.Typescript();
        if (!fs_1.default.existsSync(this.file_path)) {
            return await this.write(origin);
        }
        else if (force) {
            return await this.write(origin);
        }
        return origin;
    }
    async setBaseUrl(baseUrl) {
        const origin = await this.read();
        await this.write(Typescript_1.Typescript.merge(origin, { baseUrl }, {}));
    }
    async setModule(module) {
        const origin = await this.read();
        await this.write(Typescript_1.Typescript.merge(origin, { module }, {}));
    }
    async setTypes(types) {
        const origin = await this.read();
        await this.write(Typescript_1.Typescript.merge(origin, { types }, {}));
    }
    async setInclude(include) {
        const origin = await this.read();
        await this.write(Typescript_1.Typescript.merge(origin, {}, { include }));
    }
    async setExclude(exclude) {
        const origin = await this.read();
        await this.write(Typescript_1.Typescript.merge(origin, {}, { exclude }));
    }
    async read() {
        try {
            if (fs_1.default.existsSync(this.file_path)) {
                const origin = JSON.parse(fs_1.default.readFileSync(this.file_path, { encoding: "utf-8" }));
                return new Typescript_1.Typescript(origin);
            }
            else {
                return await this.init();
            }
        }
        catch (error) {
            console.error(error);
            process.exit(1);
        }
        return new Typescript_1.Typescript();
    }
    async write(origin) {
        try {
            const content = prettier_1.default.format(JSON.stringify(origin), const_1.PRETTIER_JSON);
            mkdir_1.mkdir(path_1.default.dirname(this.file_path));
            fs_1.default.writeFileSync(this.file_path, content, { encoding: "utf-8" });
        }
        catch (error) {
            console.error(error);
            process.exit(1);
        }
        return origin;
    }
}
exports.TypescriptConfig = TypescriptConfig;
//# sourceMappingURL=TypescriptConfig.js.map