"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const eventemitter3_1 = __importDefault(require("eventemitter3"));
const utils_1 = require("@rtcts/utils");
const chalk_1 = __importDefault(require("chalk"));
const chokidar_1 = require("chokidar");
const fs_1 = __importDefault(require("fs"));
const os_1 = __importDefault(require("os"));
const delay_1 = __importDefault(require("delay"));
const path_1 = __importDefault(require("path"));
const mkdir_1 = require("./mkdir");
const lodash_1 = require("lodash");
const find_process_1 = __importDefault(require("find-process"));
const chokidarOptions = {
    followSymlinks: false,
    ignoreInitial: true,
};
var queueEvent;
(function (queueEvent) {
    queueEvent["QUEUE_UPDATED"] = "QUEUE_UPDATED";
})(queueEvent || (queueEvent = {}));
const queueCopy = new Set();
const getProcessName = (name) => `${name}____PID:${process.pid}`;
const getPID = (name) => name.split("____PID:")[1];
class ProcessQueue {
    constructor() {
        this.tmpDirName = "rearguard";
        this.fileName = ".rearguardProcessQueue";
        this.pathToTmpDir = path_1.default.resolve(os_1.default.tmpdir(), this.tmpDirName);
        this.pathToProcessQueueFile = path_1.default.resolve(this.pathToTmpDir, this.fileName);
        this.pubSub = new eventemitter3_1.default();
        this.watcher = undefined;
        this.watcherIsActive = false;
        this.shutdownWatcher = this.shutdownWatcher.bind(this);
        this.activateWatcher = this.activateWatcher.bind(this);
        mkdir_1.mkdir(this.pathToTmpDir);
        if (!fs_1.default.existsSync(this.pathToProcessQueueFile)) {
            fs_1.default.writeFileSync(this.pathToProcessQueueFile, JSON.stringify([]));
        }
    }
    async getInQueue(name, bypassTheQueue = false) {
        if (bypassTheQueue) {
            return;
        }
        await this.removeZombie();
        const processName = getProcessName(name);
        const timeToDelay = lodash_1.random(50, 500);
        console.log(chalk_1.default.bold.gray(`[ ACTIVATE GLOBAL QUEUE OBSERVATION ]`));
        console.log("");
        console.log(chalk_1.default.gray(`[ GLOBAL QUEUE OF REARGUARD PROCESSES ]`));
        console.log(chalk_1.default.gray(`[ GET IN ][ TIME ][ ${new Date().getTime()} ][ ms ]`));
        console.log(chalk_1.default.gray(`[ TIME TO DELAY ][ ${timeToDelay} ][ ms ]`));
        console.log(chalk_1.default.gray(`[ PATH TO QUEUE ][ ${this.pathToProcessQueueFile} ]`));
        console.log("");
        await delay_1.default(timeToDelay);
        const queue = this.getQueue(this.pathToProcessQueueFile);
        console.log(chalk_1.default.bold.gray(`[ CURRENT QUEUE ][ ${queue.join(", ")} ]`));
        console.log("");
        queue.push(processName);
        queueCopy.add(processName);
        fs_1.default.writeFileSync(this.pathToProcessQueueFile, new Uint8Array(Buffer.from(JSON.stringify(queue))));
        if (queue.length === 1) {
            return;
        }
        this.activateWatcher();
        return new Promise((resolve, reject) => {
            const queueHandler = (queue) => {
                try {
                    if (utils_1.isArray(queue)) {
                        if (processName === queue[0]) {
                            this.pubSub.off(queueEvent.QUEUE_UPDATED, queueHandler);
                            resolve();
                        }
                    }
                    else {
                        throw new Error("Queue should be a string[]");
                    }
                }
                catch (error) {
                    console.error(error);
                    this.pubSub.off(queueEvent.QUEUE_UPDATED, queueHandler);
                    reject(error);
                }
            };
            this.pubSub.on(queueEvent.QUEUE_UPDATED, queueHandler);
        });
    }
    async getOutQueue(name, bypassTheQueue = false) {
        if (bypassTheQueue) {
            return;
        }
        const processName = getProcessName(name);
        let queue = this.getQueue(this.pathToProcessQueueFile);
        queue = queue.filter((item) => item !== processName);
        queueCopy.delete(processName);
        console.log(chalk_1.default.gray(`[ GLOBAL QUEUE OF REARGUARD PROCESSES ]`));
        console.log(chalk_1.default.gray(`[ GET OUT ]`));
        console.log(chalk_1.default.gray(`[ PATH TO QUEUE ][ ${this.pathToProcessQueueFile} ]`));
        console.log("");
        console.log(chalk_1.default.bold.gray(`[ CURRENT QUEUE ][ ${queue.join(", ")} ]`));
        console.log("");
        fs_1.default.writeFileSync(this.pathToProcessQueueFile, new Uint8Array(Buffer.from(JSON.stringify(queue))));
        this.shutdownWatcher();
    }
    async removeZombie() {
        let queue = this.getQueue(this.pathToProcessQueueFile);
        const zombie = [];
        for (const name of queue) {
            const PID = getPID(name);
            const process = await find_process_1.default("pid", PID);
            if (process.length === 0) {
                zombie.push(name);
            }
        }
        queue = queue.filter((name) => !zombie.includes(name));
        fs_1.default.writeFileSync(this.pathToProcessQueueFile, new Uint8Array(Buffer.from(JSON.stringify(queue))));
    }
    activateWatcher() {
        if (!this.watcherIsActive) {
            const watcher = chokidar_1.watch(this.pathToProcessQueueFile, chokidarOptions);
            const errorHandler = (error) => {
                this.shutdownWatcher();
                console.error(error);
            };
            watcher.on("error", errorHandler);
            watcher.on("ready", () => {
                watcher.off("error", errorHandler);
                watcher.on("error", (error) => console.error(error));
                this.watcherIsActive = true;
            });
            watcher.on("all", (type, pathToProcessQueueFile) => {
                this.pubSub.emit(queueEvent.QUEUE_UPDATED, this.getQueue(pathToProcessQueueFile));
            });
            this.watcher = watcher;
        }
    }
    shutdownWatcher() {
        console.log(chalk_1.default.bold.gray(`[ SHUTDOWN GLOBAL QUEUE OBSERVATION ]`));
        console.log("");
        if (this.watcher) {
            this.watcher.close();
            this.watcherIsActive = false;
            this.watcher = undefined;
        }
        if (queueCopy.size > 0) {
            const queue = this.getQueue(this.pathToProcessQueueFile).filter((item) => !queueCopy.has(item));
            fs_1.default.writeFileSync(this.pathToProcessQueueFile, new Uint8Array(Buffer.from(JSON.stringify(queue))));
            queueCopy.clear();
        }
    }
    getQueue(pathToProcessQueueFile) {
        if (fs_1.default.existsSync(pathToProcessQueueFile)) {
            const JSONString = fs_1.default.readFileSync(pathToProcessQueueFile, { encoding: "utf-8" });
            try {
                const queue = JSON.parse(JSONString);
                const result = [];
                if (utils_1.isArray(queue)) {
                    for (const item of queue) {
                        if (utils_1.isString(item)) {
                            result.push(item);
                        }
                        else {
                            throw new Error("Every item of queue should be a string");
                        }
                    }
                }
                else {
                    throw new Error("Queue should be a string[]");
                }
                return result;
            }
            catch (error) {
                console.error(error);
                console.log(chalk_1.default.bold.red("[ JSONString ]"));
                console.log(chalk_1.default.bold.red(JSONString));
                console.log("");
                fs_1.default.writeFileSync(this.pathToProcessQueueFile, JSON.stringify([]));
            }
        }
        return [];
    }
}
exports.processQueue = new ProcessQueue();
//# sourceMappingURL=processQueue.js.map