"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const prettier_1 = __importDefault(require("prettier"));
const util_1 = require("util");
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const const_1 = require("../../const");
const Template_1 = require("../Template");
const rmdir = util_1.promisify(fs_1.default.rmdir);
const exists = util_1.promisify(fs_1.default.exists);
class VSCodeTemplate extends Template_1.Template {
    async render(templateData = { force: false, forceRender: false }, CWD = process.cwd()) {
        if (templateData.forceRender || !(await this.isPartOfMonoRepository(path_1.default.resolve(CWD, "..")))) {
            await super.render(templateData, CWD);
        }
        else if (templateData.force) {
            await rmdir(path_1.default.resolve(CWD, ".vscode"), { recursive: true });
        }
    }
    prepareContent() {
        return prettier_1.default.format(this.sourceContent, const_1.PRETTIER_JSON);
    }
    async isPartOfMonoRepository(CWD, deep = 0) {
        if (deep > 4) {
            return false;
        }
        if (await exists(path_1.default.resolve(CWD, const_1.PACKAGE_JSON_FILE_NAME))) {
            const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
            if (rearguardConfig.isMono()) {
                return true;
            }
        }
        return this.isPartOfMonoRepository(path_1.default.resolve(CWD, ".."), deep + 1);
    }
}
exports.vsCodeSettingsTemplate = new VSCodeTemplate("settings.json", ".vscode/settings.json", __dirname);
exports.vsCodeExtensionsTemplate = new VSCodeTemplate("extensions.json", ".vscode/extensions.json", __dirname);
//# sourceMappingURL=index.js.map