"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("@rtcts/utils");
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const mini_css_extract_plugin_1 = __importDefault(require("mini-css-extract-plugin"));
const RearguardConfig_1 = require("../../configs/RearguardConfig");
exports.getCSSLoader = (CWD, isDevelopment, isDebug) => {
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const contextPath = path_1.default.resolve(CWD, rearguardConfig.getContext());
    const browserslist = rearguardConfig.getBrowserslist();
    const [filenameWithExternalPostCSSPlugins, useOnlyIsomorphicStyleLoader,] = rearguardConfig.getCSS();
    const externalPostCSSPluginsPath = path_1.default.resolve(CWD, filenameWithExternalPostCSSPlugins);
    let externalPostCSSPlugins = [];
    if (fs_1.default.existsSync(externalPostCSSPluginsPath)) {
        const result = require(externalPostCSSPluginsPath);
        if (utils_1.isArray(result)) {
            externalPostCSSPlugins = result;
        }
    }
    const style = { loader: "style-loader" };
    const isomorphicStyle = { loader: "isomorphic-style-loader" };
    const getCSSLoader = (options = {}) => {
        return {
            loader: "css-loader",
            options: {
                sourceMap: isDebug,
                ...options,
            },
        };
    };
    const postCss = {
        loader: "postcss-loader",
        options: {
            ident: "postcss",
            plugins: () => [
                require("postcss-import")({ path: contextPath }),
                require("postcss-css-variables")(),
                require("postcss-flexbugs-fixes")(),
                require("postcss-preset-env")({
                    features: {
                        ["case-insensitive-attributes"]: true,
                        ["all-property"]: {
                            reset: "inherited",
                        },
                        ["color-functional-notation"]: true,
                        ["custom-media-queries"]: true,
                        ["media-query-ranges"]: true,
                        ["nesting-rules"]: true,
                        ["custom-properties"]: true,
                    },
                    autoprefixer: {
                        flexbox: "no-2009",
                        overrideBrowserslist: browserslist,
                    },
                    stage: 3,
                    browsers: browserslist,
                }),
                require("postcss-normalize")({ browsers: browserslist }),
                ...externalPostCSSPlugins,
            ],
        },
    };
    const sass = [
        {
            loader: "resolve-url-loader",
            options: {
                sourceMap: isDebug,
            },
        },
        {
            loader: "sass-loader",
            options: {
                sourceMap: isDebug,
            },
        },
    ];
    const localIdentName = (isDevelopment) => {
        return isDevelopment ? "[path][local][hash:base64:4]" : "[hash:base64:32]";
    };
    if (useOnlyIsomorphicStyleLoader) {
        const cssIsomorphicRegex = /\.css$/;
        const sassIsomorphicRegex = /\.(scss|sass)$/;
        const cssIsomorphicModuleRegex = /\.module\.css$/;
        const sassIsomorphicModuleRegex = /\.module\.(scss|sass)$/;
        return [
            {
                test: cssIsomorphicRegex,
                exclude: cssIsomorphicModuleRegex,
                use: [isomorphicStyle, getCSSLoader({ importLoaders: 1 }), postCss],
                sideEffects: true,
            },
            {
                test: sassIsomorphicRegex,
                exclude: sassIsomorphicModuleRegex,
                use: [isomorphicStyle, getCSSLoader({ importLoaders: 2 }), postCss, ...sass],
                sideEffects: true,
            },
            {
                test: cssIsomorphicModuleRegex,
                use: [
                    isomorphicStyle,
                    getCSSLoader({
                        importLoaders: 1,
                        modules: { localIdentName: localIdentName(isDevelopment) },
                    }),
                    postCss,
                ],
            },
            {
                test: sassIsomorphicModuleRegex,
                use: [
                    isomorphicStyle,
                    getCSSLoader({
                        importLoaders: 2,
                        modules: { localIdentName: localIdentName(isDevelopment) },
                    }),
                    postCss,
                    ...sass,
                ],
            },
        ];
    }
    else {
        const cssRegex = /\.css$/;
        const sassRegex = /\.(scss|sass)$/;
        const cssModuleRegex = /\.module\.css$/;
        const sassModuleRegex = /\.module\.(scss|sass)$/;
        return [
            {
                test: cssRegex,
                exclude: cssModuleRegex,
                use: [
                    ...(isDevelopment ? [style] : [mini_css_extract_plugin_1.default.loader]),
                    getCSSLoader({ importLoaders: 1 }),
                    postCss,
                ],
                sideEffects: true,
            },
            {
                test: sassRegex,
                exclude: sassModuleRegex,
                use: [
                    ...(isDevelopment ? [style] : [mini_css_extract_plugin_1.default.loader]),
                    getCSSLoader({ importLoaders: 2 }),
                    postCss,
                    ...sass,
                ],
                sideEffects: true,
            },
            {
                test: cssModuleRegex,
                use: [
                    ...(isDevelopment ? [style] : [mini_css_extract_plugin_1.default.loader]),
                    getCSSLoader({
                        importLoaders: 1,
                        modules: { localIdentName: localIdentName(isDevelopment) },
                    }),
                    postCss,
                ],
            },
            {
                test: sassModuleRegex,
                use: [
                    ...(isDevelopment ? [style] : [mini_css_extract_plugin_1.default.loader]),
                    getCSSLoader({
                        importLoaders: 2,
                        modules: { localIdentName: localIdentName(isDevelopment) },
                    }),
                    postCss,
                    ...sass,
                ],
            },
        ];
    }
};
//# sourceMappingURL=getCSSLoader.js.map