"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const RearguardConfig_1 = require("../../configs/RearguardConfig");
const RearguardDevConfig_1 = require("../../configs/RearguardDevConfig");
const const_1 = require("../../const");
const applyHackForForceReCompile_1 = require("../../helpers/applyHackForForceReCompile");
const pubSub_1 = require("../../helpers/pubSub");
const getWebpackStats_1 = require("./getWebpackStats");
exports.getWebpackDevServerConfig = async (CWD, isDevelopment) => {
    const rearguardLocalConfig = new RearguardDevConfig_1.RearguardDevConfig(CWD);
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const context = rearguardConfig.getContext();
    const entry = rearguardConfig.getEntry();
    const { proxy } = await rearguardLocalConfig.getWDSConfig();
    const pathToEntryPoint = path_1.default.resolve(CWD, context, entry);
    let needReloadBrowser = false;
    return {
        http2: true,
        compress: true,
        contentBase: [const_1.DLL_BUNDLE_DIR_NAME, const_1.LIB_BUNDLE_DIR_NAME, const_1.PUBLIC_DIR_NAME],
        watchContentBase: false,
        useLocalIp: true,
        before(app, server) {
            pubSub_1.pubSub.on(pubSub_1.events.SYNCED, async () => {
                await applyHackForForceReCompile_1.applyHackForForceReCompile(pathToEntryPoint);
                needReloadBrowser = true;
            });
            pubSub_1.pubSub.on(pubSub_1.events.RELOAD_BROWSER, () => {
                if (needReloadBrowser) {
                    server.middleware.waitUntilValid(() => {
                        console.log("");
                        console.log("[ WDS ][ RELOAD_BROWSER ]");
                        console.log("");
                        server.sockWrite(server.sockets, "content-changed");
                        needReloadBrowser = false;
                    });
                }
            });
        },
        historyApiFallback: true,
        hot: isDevelopment,
        liveReload: isDevelopment,
        overlay: false,
        proxy,
        publicPath: "/",
        stats: getWebpackStats_1.getWebpackStats(CWD),
        headers: {
            ["Cache-Control"]: "no-transform",
        },
    };
};
//# sourceMappingURL=getWebpackDevServerConfig.js.map