"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const moment_1 = __importDefault(require("moment"));
const lodash_1 = require("lodash");
const RearguardDevConfig_1 = require("../../../configs/RearguardDevConfig");
class HashWebpackPlugin {
    constructor(CWD, isDevelopment, needUpdateBuildTime) {
        this.isDevelopment = isDevelopment;
        this.needUpdateBuildTime = needUpdateBuildTime;
        this.rearguardLocalConfig = new RearguardDevConfig_1.RearguardDevConfig(CWD);
        this.apply = this.apply.bind(this);
    }
    apply(compiler) {
        compiler.plugin("after-emit", async (compilation, callback) => {
            const config = await this.rearguardLocalConfig.getConfig();
            const hash = compilation.hash;
            let hashType = "hash_dev";
            if (this.isDevelopment) {
                hashType = "hash_dev";
            }
            else {
                hashType = "hash_prod";
            }
            const curHash = config.build[hashType];
            if (curHash !== hash || this.needUpdateBuildTime) {
                await this.rearguardLocalConfig.setConfig(lodash_1.merge(config, { build: { last_build_time: moment_1.default() } }));
            }
            await this.rearguardLocalConfig.setConfig(lodash_1.merge(config, { build: { [hashType]: hash } }));
            callback(null);
        });
    }
}
exports.HashWebpackPlugin = HashWebpackPlugin;
//# sourceMappingURL=HashWebpackPlugin.js.map