"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const case_sensitive_paths_webpack_plugin_1 = __importDefault(require("case-sensitive-paths-webpack-plugin"));
const clean_webpack_plugin_1 = require("clean-webpack-plugin");
const fork_ts_checker_webpack_plugin_1 = __importDefault(require("fork-ts-checker-webpack-plugin"));
const pnp_webpack_plugin_1 = __importDefault(require("pnp-webpack-plugin"));
const stylelint_webpack_plugin_1 = __importDefault(require("stylelint-webpack-plugin"));
const stylelint_formatter_pretty_1 = __importDefault(require("stylelint-formatter-pretty"));
const path_1 = __importDefault(require("path"));
const resolve_1 = __importDefault(require("resolve"));
const webpack_1 = __importDefault(require("webpack"));
const RearguardConfig_1 = require("../configs/RearguardConfig");
const const_1 = require("../const");
const dependencyPaths_1 = require("../helpers/dependencyPaths");
const getChunkOptimization_1 = require("./components/getChunkOptimization");
const getCSSLoader_1 = require("./components/getCSSLoader");
const getExternals_1 = require("./components/getExternals");
const getTypescriptLoader_1 = require("./components/getTypescriptLoader");
const getManifestPlugin_1 = require("./components/plugins/getManifestPlugin");
const getMiniCssExtractPlugin_1 = require("./components/plugins/getMiniCssExtractPlugin");
const getOptimizeCSSAssetsPlugin_1 = require("./components/plugins/getOptimizeCSSAssetsPlugin");
const getTerserWebpackPlugin_1 = require("./components/plugins/getTerserWebpackPlugin");
const getWebpackBundleAnalyzerPlugin_1 = require("./components/plugins/getWebpackBundleAnalyzerPlugin");
const HashWebpackPlugin_1 = require("./components/plugins/HashWebpackPlugin");
const getENV_1 = require("../components/procedures/getENV");
exports.getGeneralWebpackConfig = async (CWD, isDevelopment, entry, output, plugins, isDebug = false, needUpdateBuildTime = false, isProfile = false, rules = [], externals = {}, isDll = false) => {
    const rearguardConfig = new RearguardConfig_1.RearguardConfig(CWD);
    const contextPath = path_1.default.resolve(CWD, rearguardConfig.getContext());
    const tsconfigFilePath = path_1.default.resolve(CWD, const_1.TS_CONFIG_FILE_NAME);
    const styleLintConfigFilePath = path_1.default.resolve(CWD, const_1.STYLE_LINT_CONFIG_FILE_NAME);
    const isBrowser = rearguardConfig.isBrowser();
    const isIsomorphic = rearguardConfig.isIsomorphic();
    const modules = [
        ...rearguardConfig.getModules(),
        dependencyPaths_1.getLocalNodeModulePath(CWD),
        dependencyPaths_1.getRearguardNodeModulesPath(CWD),
    ];
    const [eslintLoader, tsLoader] = getTypescriptLoader_1.getTypescriptLoader(CWD);
    const fileRegExp = /\.(ico|jpg|jpeg|png|gif|eot|otf|webp|svg|ttf|woff|woff2|bmp|gif)(\?.*)?$/;
    const rawFileRegExp = /\.(text|csv)(\?.*)?$/;
    return {
        mode: isDevelopment ? "development" : "production",
        bail: !isDevelopment,
        devtool: isDebug ? "source-map" : false,
        context: contextPath,
        entry,
        externals: { ...(await getExternals_1.getExternals(CWD, isDevelopment)), ...externals },
        output: {
            pathinfo: isDevelopment,
            filename: "[name].[hash:8].js",
            chunkFilename: "[name].[hash:8].chunk.js",
            globalObject: "this",
            jsonpFunction: `webpackJsonp_rearguard_${rearguardConfig.getSnakeName()}`,
            futureEmitAssets: true,
            ...output,
        },
        optimization: {
            minimize: !isDevelopment,
            minimizer: [
                ...getTerserWebpackPlugin_1.getTerserWebpackPlugin(isDevelopment),
                ...getOptimizeCSSAssetsPlugin_1.getOptimizeCSSAssetsPlugin(isDevelopment, isDebug),
            ],
            ...(isDll ? [] : getChunkOptimization_1.getChunkOptimization(CWD)),
        },
        resolve: {
            modules,
            extensions: [".ts", ".tsx", ".css", ".scss", ".sass", ".js", ".jsx", ".json"],
            alias: {
                ...(isProfile
                    ? {
                        "react-dom$": "react-dom/profiling",
                        "scheduler/tracing": "scheduler/tracing-profiling",
                    }
                    : {}),
            },
            plugins: [pnp_webpack_plugin_1.default],
        },
        resolveLoader: {
            modules,
            extensions: [".js", ".json"],
            mainFields: ["loader", "main"],
            plugins: [pnp_webpack_plugin_1.default.moduleLoader(module)],
        },
        module: {
            strictExportPresence: true,
            rules: [
                { parser: { requireEnsure: false } },
                eslintLoader,
                {
                    oneOf: [
                        {
                            test: fileRegExp,
                            loader: "url-loader",
                            options: {
                                limit: 10240,
                                name: "[name].[hash:8].[ext]",
                            },
                        },
                        tsLoader,
                        ...getCSSLoader_1.getCSSLoader(CWD, isDevelopment, isDebug),
                        ...rules,
                        {
                            test: rawFileRegExp,
                            use: "raw-loader",
                        },
                        {
                            loader: "file-loader",
                            test: fileRegExp,
                            query: {
                                name: isDevelopment ? "[path][name].[ext]?[hash:8]" : "[hash:32].[ext]",
                            },
                        },
                    ],
                },
            ],
        },
        plugins: [
            new case_sensitive_paths_webpack_plugin_1.default(),
            new clean_webpack_plugin_1.CleanWebpackPlugin({ verbose: true }),
            new webpack_1.default.DefinePlugin(getENV_1.getENV(CWD)),
            new webpack_1.default.ProgressPlugin(),
            new webpack_1.default.WatchIgnorePlugin([/node_modules/, /webpack-dll-manifest.json/]),
            new webpack_1.default.IgnorePlugin(/^\.\/locale$/, /moment$/),
            ...(isBrowser || isIsomorphic
                ? [
                    new stylelint_webpack_plugin_1.default({
                        stylelintPath: resolve_1.default.sync("stylelint", {
                            basedir: dependencyPaths_1.getLocalNodeModulePath(CWD),
                        }),
                        configFile: styleLintConfigFilePath,
                        context: contextPath,
                        fix: isDevelopment,
                        files: "**/*.css",
                        formatter: stylelint_formatter_pretty_1.default,
                    }),
                ]
                : []),
            ...plugins,
            ...getMiniCssExtractPlugin_1.getMiniCssExtractPlugin(CWD, isDevelopment),
            ...getManifestPlugin_1.getManifestPlugin(CWD, output, isDevelopment),
            new fork_ts_checker_webpack_plugin_1.default(pnp_webpack_plugin_1.default.forkTsCheckerOptions({
                typescript: resolve_1.default.sync("typescript", {
                    basedir: dependencyPaths_1.getLocalNodeModulePath(CWD),
                }),
                async: isDevelopment,
                useTypescriptIncrementalApi: true,
                checkSyntacticErrors: true,
                tsconfig: tsconfigFilePath,
                reportFiles: [
                    "**",
                    "!**/__tests__/**",
                    "!**/?(*.)(spec|test).*",
                    "!**/src/setupProxy.*",
                    "!**/src/setupTests.*",
                ],
                silent: true,
            })),
            new HashWebpackPlugin_1.HashWebpackPlugin(CWD, isDevelopment, needUpdateBuildTime),
            ...(await getWebpackBundleAnalyzerPlugin_1.getWebpackBundleAnalyzerPlugin(CWD, isDebug)),
        ],
        node: {
            __filename: "mock",
            __dirname: "mock",
            module: "empty",
            dgram: "empty",
            dns: "mock",
            fs: "empty",
            http2: "empty",
            net: "empty",
            tls: "empty",
            child_process: "empty",
            utils: "empty",
        },
        profile: true,
    };
};
//# sourceMappingURL=webpack.config.common.js.map